@@ -1,8 +1,8 @@
-﻿import matplotlib.pyplot as plt
-import matplotlib.gridspec as gridspec
-import bzplot as bp
-import numpy as np
+﻿import bzplot as bp
 import matplotlib as mpl
+import matplotlib.gridspec as gridspec
+import matplotlib.pyplot as plt
+import numpy as np
 
 # more advanced example of the two cuts plotted together and aligned
 f = plt.figure()
