@@ -2,10 +2,12 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2021, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
+# pylint: disable=wrong-import-position, wrong-import-order
+
 from ufit.version import get_version
 
 __version__ = get_version()
@@ -15,14 +17,16 @@ class UFitError(Exception):
     pass
 
 import matplotlib
+
 try:
     import ufit.qt
-    matplotlib.use('Qt5Agg')
-except:
+    matplotlib.use('qtagg')
+except Exception:
     pass
 
-from ufit.result import *
-from ufit.param import *
-from ufit.data import *
-from ufit.models import *
 from ufit.backends import *
+from ufit.data import *
+from ufit.param import *
+from ufit.result import *
+
+from ufit.models import *  # isort: skip
