@@ -2,7 +2,7 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2021, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
@@ -36,7 +36,7 @@ def do_fit(data, fcn, params, add_kw):
         update_params(dependent, meta, pd)
         return (fcn(pd, x) - y) / dy
 
-    printReport = add_kw.pop('printReport', False)
+    print_report = add_kw.pop('printReport', False)
 
     try:
         out = minimize(lmfitfcn, lmfparams, args=(data,), **add_kw)
@@ -44,7 +44,7 @@ def do_fit(data, fcn, params, add_kw):
         print(str(e))
         return False, str(e), 0
 
-    if printReport:
+    if print_report:
         report_fit(out.params)
 
     pd = dict((pn, out.params[pn].value) for pn in varynames)
@@ -52,8 +52,8 @@ def do_fit(data, fcn, params, add_kw):
     for p in params:
         p.value = pd[p.name]
         if p.name in lmfparams:
-            p.error = out.params[p.name].stderr
-            p.correl = out.params[p.name].correl
+            p.error = out.params[p.name].stderr or 0
+            p.correl = out.params[p.name].correl or {}
         else:
             p.error = 0
             p.correl = {}
