@@ -2,17 +2,17 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2021, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
 """Backend using iminuit."""
 
+from iminuit import Minuit
+
 from ufit.param import prepare_params, update_params
 from ufit.utils import get_chisqr
 
-from iminuit import Minuit
-
 __all__ = ['do_fit', 'backend_name']
 
 backend_name = 'minuit'
@@ -28,10 +28,10 @@ def do_fit(data, fcn, params, add_kw):
         update_params(dependent, meta, pd)
         return ((fcn(pd, x) - y)**2 / dy**2).sum()
 
-    printReport = add_kw.pop('printReport', False)
+    print_report = add_kw.pop('printReport', False)
 
     marg = dict(
-        print_level=int(printReport),
+        print_level=int(print_report),
         forced_parameters=varynames,
     )
     marg.update(add_kw)
