@@ -2,13 +2,13 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2021, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
 """Backend using plain scipy leastsq."""
 
-from numpy import sqrt, inf
+from numpy import inf, sqrt
 from scipy.optimize import leastsq
 
 from ufit.param import prepare_params, update_params
@@ -42,7 +42,7 @@ def do_fit(data, fcn, params, add_kw):
     except Exception as e:
         return False, str(e), 0
 
-    popt, pcov, infodict, errmsg, ier = res
+    popt, pcov, _infodict, errmsg, ier = res
     success = (ier in [1, 2, 3, 4])
 
     nfree = len(y) - len(varying)
