@@ -2,7 +2,7 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2021, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
@@ -10,9 +10,10 @@
 
 from copy import copy
 from time import time
-from numpy import sqrt, infty, ones, zeros, absolute, maximum, minimum, \
-    finfo, corrcoef, nonzero, diag, isnan, dot
-from numpy.linalg import svd, pinv
+
+from numpy import absolute, corrcoef, diag, dot, finfo, inf, isnan, \
+    maximum, minimum, nonzero, ones, sqrt, zeros
+from numpy.linalg import pinv, svd
 
 from ufit.param import prepare_params, update_params
 from ufit.utils import get_chisqr
@@ -45,7 +46,6 @@ def do_fit(data, fcn, params, add_kw):
         res = __leastsq((x, y, dy), leastsqfcn, initpars, initdp,
                         **add_kw)
     except Exception as e:
-        raise
         return False, str(e), 0
 
     success = res['converged']
@@ -79,7 +79,7 @@ def __dfdp(x, f, p, dp, func):
     # pp = copy(p)
     dpp = copy(dp)
 
-    for i in range(len(p)):
+    for i in range(len(p)):  # pylint: disable=consider-using-enumerate
         pp = copy(p)
         if dpp[i] == 0.0:
             dpp[i] = 0.00001
@@ -95,10 +95,12 @@ def __leastsq(xyw, func, p, dp, niter=50, mode='print', eps=1e-3):
              ---------------
     OPTIONS IN:
       niter (integ) : maximal number of iterations (50 is default).
-      mode (string) : can be 'print' or 'silent'. In silent mode output is not written to standard out
+      mode (string) : can be 'print' or 'silent'. In silent mode output is not
+                      written to standard out
                       but is saved in a message string.
 
-    Author:  EF <manuf@ldv.univ-montp2.fr>, RM <rfm2@ds2.uh.cwru.edu>, AJ <jutan@charon.engga.uwo.ca>
+    Author:  EF <manuf@ldv.univ-montp2.fr>, RM <rfm2@ds2.uh.cwru.edu>,
+    AJ <jutan@charon.engga.uwo.ca>
     Description: Non Linear Least Square multivariable fit.
 
     Adapted for Octave : E.Farhi.   04/98   (manuf@ldv.univ-montp2.fr)
@@ -115,69 +117,71 @@ def __leastsq(xyw, func, p, dp, niter=50, mode='print', eps=1e-3):
     Draper and Smith, Applied Regression Analysis, John Wiley and Sons, 1981.
     """
     (x, y, wt) = xyw
-    options = zeros((len(p),2))            #desired fractional precision in parameter estimates.
-    options[:,1] = ones(len(p)) * infty    #maximum fractional step change in parameter vector.
-                        #not yet implemented standards are set (zero for precision, infty for max change)
-    #instr_p = self.add_pars                                #additional parameters that are NOT fitted
-    #func = self.__getfunc(self.func, self.add_pars)        #python function object of the form 'y=f(x,instr_p)'.
+    options = zeros((len(p), 2))  # desired fractional precision in parameter estimates.
+    # maximum fractional step change in parameter vector.
+    options[:, 1] = ones(len(p)) * inf
+    # not yet implemented standards are set (zero for precision, inf for max change)
+    # instr_p = self.add_pars  #additional parameters that are NOT fitted
+    # python function object of the form 'y=f(x,instr_p)'.
+    # func = self.__getfunc(self.func, self.add_pars)
 
-    stol = eps      #tolerance on square error sum fractional improvement (1e-3 is default)
+    stol = eps  # tolerance on square error sum fractional improvement (1e-3 is default)
 
-
-    #cycle message (mainly for silent mode)
+    # cycle message (mainly for silent mode)
     cyclemsg = ''
     errmsg = ''
 
     if not all(dp):
         raise FitError('no dp given for some parameters')
 
-    #check if data vector have the same length
+    # check if data vector have the same length
     m = len(y)
     n = len(p)
-    ##w = len(wt)
+    # w = len(wt)
     sh = x.shape
     m1 = sh[0]
-    ##if len(sh) > 1:
-    ##    m2 = sh[1]
-    ##else:
-    ##    m2 = 1
+    # if len(sh) > 1:
+    #     m2 = sh[1]
+    # else:
+    #     m2 = 1
 
     if m1 != m:
-      raise FitError('Input(x)/output(y) data must have same number of rows!')
+        raise FitError('Input(x)/output(y) data must have same number of rows!')
 
     if len(options) == 0:
-        options = zeros((n,2))
-        options[:,1] = ones(n) * infty
+        options = zeros((n, 2))
+        options[:, 1] = ones(n) * inf
     else:
         nor, noc = options.shape
 
         if nor != n:
-            raise FitError('Options and parameter matrices must have same number of rows!')
+            raise FitError('Options and parameter matrices must have same '
+                           'number of rows!')
 
         if noc != 2:
-            options = zeros((n,2))
-            options[:,1] = ones(n) * infty
+            options = zeros((n, 2))
+            options[:, 1] = ones(n) * inf
 
-    pprec = options[:,0]
-    maxstep = options[:,1]
+    pprec = options[:, 0]
+    maxstep = options[:, 1]
 
-    #apply parameter constraints
-    ##p = self.__apply_constraints(p)
+    # apply parameter constraints
+    # p = self.__apply_constraints(p)
 
-    #setup for iterations (with initial data)
+    # setup for iterations (with initial data)
     f = func(x, p)
-    fbest = copy(f)              #initial function values
-    pbest = copy(p)              #initial parameters
-    r     = wt*(y-f)             #error (elementwise multiplication of columnvectors
-    sbest = dot(r,r)
+    fbest = copy(f)   # initial function values
+    pbest = copy(p)   # initial parameters
+    r     = wt*(y-f)  # error (elementwise multiplication of columnvectors
+    sbest = dot(r, r)
     ss = sbest
     nrm = zeros(n)
-    chgprev = infty*ones(n)
+    chgprev = inf*ones(n)
     kvg = False
-    epsLlast = 1
+    epsllast = 1
     epstab = [0.1, 1, 1e2, 1e4, 1e6]
 
-    #print header for fitting cycles if direct output was demanded by user
+    # print header for fitting cycles if direct output was demanded by user
     if mode == 'print':
         print('Iteration  Time(s)  Residual Variance')
         print('=====================================')
@@ -185,75 +189,76 @@ def __leastsq(xyw, func, p, dp, niter=50, mode='print', eps=1e-3):
 
     for iteration in range(niter):
         t0 = time()
-        pprev = copy(pbest) #current paras
-        #print pprev
-        prt   = __dfdp(x, fbest, pprev, dp, func) #partials of func for x
-        r     = wt*(y-fbest)        #error
-        sprev = copy(sbest)        #square error
-        sgoal = (1-stol)*sprev        #square error to achieve
+        pprev = copy(pbest)  # current paras
+        # print pprev
+        prt   = __dfdp(x, fbest, pprev, dp, func)  # partials of func for x
+        r     = wt*(y-fbest)    # error
+        sprev = copy(sbest)     # square error
+        sgoal = (1-stol)*sprev  # square error to achieve
 
-        for j in range(n):        #compute partials norm
+        for j in range(n):      # compute partials norm
             if dp[j] == 0.0:
                 nrm[j] = 0.0
             else:
-                prt[:,j] = wt*prt[:,j]
-                nrm[j]   = dot(prt[:,j],prt[:,j])
+                prt[:, j] = wt*prt[:, j]
+                nrm[j]   = dot(prt[:, j], prt[:, j])
                 if nrm[j] > 0:
                     nrm[j] = 1./sqrt(nrm[j])
 
-            prt[:,j] = nrm[j]*prt[:,j]    #normalizes partials
+            prt[:, j] = nrm[j]*prt[:, j]  # normalizes partials
 
-        prt,s,v = svd(prt, full_matrices=False)        #prt=unit matr, s=eigenval : prt=prt*s*v.T
+        prt, s, v = svd(prt, full_matrices=False)
+        # prt=unit matr, s=eigenval : prt=prt*s*v.T
         v = v.T
-        g = dot(prt.T,r)            #gradient by Gauss-Newton formula
+        g = dot(prt.T, r)  # gradient by Gauss-Newton formula
 
-        for k in range(len(epstab)):
-            epsL = maximum(epsLlast*epstab[k],1e-7)
-            se  = sqrt(s*s+epsL)
+        for k in range(len(epstab)):  # pylint: disable=consider-using-enumerate
+            epsl = maximum(epsllast*epstab[k], 1e-7)
+            se  = sqrt(s*s+epsl)
             gse = g/se
-            chg = dot(v,gse)*nrm    #change on params
-                        #check the change constraints and apply is necessary
+            chg = dot(v, gse)*nrm  # change on params
+            # check the change constraints and apply if necessary
             for l in range(n):
-                if maxstep[l] == infty:
+                if maxstep[l] == inf:
                     break
                 chg[l] = maximum(chg[l], -1 * absolute(maxstep[l]*pprev[l]))
                 chg[l] = minimum(chg[l], absolute(maxstep[l]*pprev[l]))
 
             aprec = absolute(pprec*pbest)
             if any(absolute(chg) > 0.1*aprec):
-                #only worth evaluating function if there is some non-miniscule change
+                # only worth evaluating function if there is some non-miniscule change
                 p = chg+pprev
 
-                #apply parameter constraints
-                ##p = self.__apply_constraints(p)
+                # apply parameter constraints
+                # p = self.__apply_constraints(p)
 
                 f = func(x, p)
                 r = wt*(y-f)
-                ss = dot(r,r)
+                ss = dot(r, r)
                 if ss < sbest:
                     pbest = copy(p)
                     fbest = copy(f)
                     sbest = copy(ss)
 
                 if ss <= sgoal:
-                    #print 'ss <= sgoal', ss, sgoal
+                    # print 'ss <= sgoal', ss, sgoal
                     break
 
-        epsLlast = epsL
+        epsllast = epsl
         if ss < finfo(float).eps:
             print('Sum of squares within machine precision')
-            break # machine precession
+            break  # machine precession
 
-        aprec=absolute(pprec*pbest)
-        if ((absolute(chg)).all() < aprec.all()) and ((absolute(chgprev)).all() < aprec.all()):
+        aprec = absolute(pprec*pbest)
+        if absolute(chg).all() < aprec.all() and absolute(chgprev).all() < aprec.all():
             kvg = True
             print('Parameter changes converged to specified precision')
             break
-        else:
-            chgprev = chg
-            if ss > sgoal:
-                #print 'ss > sgoal in outer loop!'
-                break
+
+        chgprev = chg
+        if ss > sgoal:
+            # print 'ss > sgoal in outer loop!'
+            break
 
         dt = time()-t0
         cyclemsg = '%5i    %7.2f    %8.3f' % (iteration+1, dt, ss/len(y))
@@ -262,7 +267,7 @@ def __leastsq(xyw, func, p, dp, niter=50, mode='print', eps=1e-3):
 
     kvg = (sbest > sgoal)
 
-    #set return values
+    # set return values
     p = copy(pbest)
     f = copy(fbest)
     ss = copy(sbest)
@@ -273,17 +278,17 @@ def __leastsq(xyw, func, p, dp, niter=50, mode='print', eps=1e-3):
     else:
         print('===== Converged =====================')
 
-    #Calculate R (Ref Draper & Smith p.46)
-    r=corrcoef(y*wt,f*wt)
-    r2=r*r.T
+    # calculate R (Ref Draper & Smith p.46)
+    r = corrcoef(y*wt, f*wt)
+    r2 = r*r.T
     ss = sum(wt*(f-y))/len(y)
 
-    #calculate variance cov matrix and correlation matrix of parameters
-    #re-evaluate the Jacobian at optimal values
+    # calculate variance cov matrix and correlation matrix of parameters
+    # re-evaluate the Jacobian at optimal values
     jac = __dfdp(x, fbest, pprev, dp, func)
-    ##msk = nonzero(dp)[0]
-    ##n = len(msk)        # dfdp(x,fbest,pprev,dp,func, instr_p)
-    ##jac = jac[:,msk]        # use only fitted parameters
+    # msk = nonzero(dp)[0]
+    # n = len(msk)        # dfdp(x,fbest,pprev,dp,func, instr_p)
+    # jac = jac[:,msk]        # use only fitted parameters
 
     # following section is Ray Muzic's estimate for covariance and correlation
     # assuming covariance of data is a diagonal matrix proportional to
@@ -293,26 +298,28 @@ def __leastsq(xyw, func, p, dp, niter=50, mode='print', eps=1e-3):
     Qinv = diag(wt*wt)
     Q = diag((0*wt+1)/(wt**2))
 
-    resid = y-f            #unweighted residuals
-    covr=dot(resid.T,dot(Qinv,dot(resid,Q)))/(m-n) # covariance of residuals
-    Vy=1/(1-n/m)*covr          # Eq. 7-13-22, Bard    covariance of the data
+    resid = y-f            # unweighted residuals
+    covr = dot(resid.T, dot(Qinv, dot(resid, Q)))/(m-n)  # covariance of residuals
+    Vy = 1/(1-n/m)*covr    # Eq. 7-13-22, Bard    covariance of the data
 
-    jtgjinv=pinv(dot(jac.T,dot(Qinv,jac))) #pinv = pseudo-inverse of matrix
+    jtgjinv = pinv(dot(jac.T, dot(Qinv, jac)))  # pinv = pseudo-inverse of matrix
 
     if not isnan(jtgjinv).all():
         # Eq. 7-5-13, Bard cov of parmater estimates
-        covp = dot(jtgjinv,dot(jac.T,dot(Qinv,dot(Vy,dot(Qinv,dot(jac,jtgjinv))))))
+        covp = dot(jtgjinv, dot(jac.T, dot(Qinv, dot(Vy, dot(Qinv, dot(jac, jtgjinv))))))
 
-        corp = ones((n,n))
+        corp = ones((n, n))
         for k in range(n):
-            for j in range(k,n):
-                if covp[k,k]*covp[j,j]:
-                    corp[k,j] = covp[k,j]/sqrt(abs(covp[k,k]*covp[j,j]))
+            for j in range(k, n):
+                # pylint: disable=invalid-sequence-index
+                if covp[k, k]*covp[j, j]:
+                    corp[k, j] = covp[k, j]/sqrt(abs(covp[k, k]*covp[j, j]))
 
     else:
-        errmsg += "Warning : leasqr : couldn\'t compute squared Jacobian inverse matrix (no covp, no corp).\n"
-        covp = zeros((n,n))
-        corp = ones((n,n))
+        errmsg += "Warning : leasqr : couldn\'t compute squared Jacobian " \
+            "inverse matrix (no covp, no corp).\n"
+        covp = zeros((n, n))
+        corp = ones((n, n))
 
     deltap = sqrt(diag(covp))
 
@@ -320,15 +327,15 @@ def __leastsq(xyw, func, p, dp, niter=50, mode='print', eps=1e-3):
     res['values'] = []
     res['errors'] = []
 
-    for i in range(len(p)):
-        res['values'].append(p[i])
-        res['errors'].append(deltap[i])
+    for p_i, d_i in zip(p, deltap):
+        res['values'].append(p_i)
+        res['errors'].append(d_i)
 
-    #work out chi2
+    # work out chi2
     v = len(y) - len(nonzero(dp))
     ChiSq = sum((wt*(f-y))**2)/v
 
-    #write back results:
+    # write back results:
     res['converged'] = kvg
     res['cycles'] = iteration
 
