@@ -2,13 +2,14 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2022, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
-import numpy as np
 from enum import Enum
 
+import numpy as np
+
 _marker_size = 10
 _bz_width = 0.5
 _label_size = 18
@@ -16,16 +17,16 @@ inva = np.array([-1, 1])
 
 
 class PlaneType(Enum):
-    hhlplane = 0
-    h0lplane = 1
-    hk0plane = 2
+    HHLPLANE = 0
+    H0LPLANE = 1
+    HK0PLANE = 2
 
-    def GetVector(input):
-        if input == PlaneType.h0lplane:
+    def GetVector(inp):  # pylint: disable=no-self-argument
+        if inp == PlaneType.H0LPLANE:
             return (0, 1, 0)
-        elif input == PlaneType.hk0plane:
+        if inp == PlaneType.HK0PLANE:
             return (0, 0, 1)
-        elif input == PlaneType.hhlplane:
+        if inp == PlaneType.HHLPLANE:
             return (1, -1, 0)
         raise NotImplementedError
 
@@ -54,25 +55,25 @@ class BZCreator:
             # "Gamma": [0, 0, 0],
         }
         self.gpts = gpts
-        if (plane[0] == plane[1] == 0):
-            self.pt = PlaneType.hk0plane
+        if plane[0] == plane[1] == 0:
+            self.pt = PlaneType.HK0PLANE
         elif (plane[2] == 0) and (plane[0] == 0 or plane[1] == 0):
-            self.pt = PlaneType.h0lplane
+            self.pt = PlaneType.H0LPLANE
         elif (plane[2] == 0) and (abs(plane[1]) == abs(plane[0])):
-            self.pt = PlaneType.hhlplane
+            self.pt = PlaneType.HHLPLANE
         else:
-            raise(NotImplementedError)
+            raise NotImplementedError
 
-    def doPlot(self, plt, alph = 0.1, showLabels = True, lw = _bz_width):
+    def doPlot(self, plt, alph=0.1, show_labels=True, lw=_bz_width):
 
         plt.plot(self.gpts[:, 0], self.gpts[:, 1], 'o',
-                 markersize=_marker_size + 3, alpha = alph)
+                 markersize=_marker_size + 3, alpha=alph)
 
         # pts
         pts = self.getPts()
         for p in pts:
             plt.plot(p[:, 0], p[:, 1], 'o',
-                     markersize=_marker_size, alpha = alph)
+                     markersize=_marker_size, alpha=alph)
 
         # lines
         pts = self.getLines()
@@ -80,29 +81,29 @@ class BZCreator:
             plt.plot(p[:, 0], p[:, 1], 'k--', linewidth=lw)
 
         # misc
-        if (self.pt == PlaneType.hk0plane):
+        if self.pt == PlaneType.HK0PLANE:
             plt.set_aspect(1)
             plt.set_xlabel('h (r.l.u.)', fontsize=_label_size)
             plt.set_ylabel('k (r.l.u.)', fontsize=_label_size)
-            if (showLabels):
+            if show_labels:
                 plt.text(0.07, -0.05, r'$\Gamma$', fontsize=_label_size)
                 plt.text(0.65, -0.05, r'$\Sigma$', fontsize=_label_size)
                 plt.text(0.65,  0.27, r'Y', fontsize=_label_size)
                 plt.text(0.55,  0.55, r'X', fontsize=_label_size)
-        elif (self.pt == PlaneType.h0lplane):
+        elif self.pt == PlaneType.H0LPLANE:
             plt.set_aspect(self.a/self.c)
             plt.set_xlabel('h (r.l.u.)', fontsize=_label_size)
             plt.set_ylabel('l (r.l.u.)', fontsize=_label_size)
-            if (showLabels):
+            if show_labels:
                 plt.text(0.07, -0.08, r'$\Gamma$', fontsize=_label_size)
                 plt.text(0.45, -0.08, r'$\Sigma$', fontsize=_label_size)
                 plt.text(0.57,  0.40, r'N', fontsize=_label_size)
                 plt.text(0.07,  1.07, r'Z', fontsize=_label_size)
-        elif (self.pt == PlaneType.hhlplane):
+        elif self.pt == PlaneType.HHLPLANE:
             plt.set_aspect(self.a/self.c*np.sqrt(2))
             plt.set_xlabel('h (r.l.u.)', fontsize=_label_size)
             plt.set_ylabel('l (r.l.u.)', fontsize=_label_size)
-            # if (showLabels):
+            # if show_labels:
             #     plt.text(0.07, -0.08, r'$\Gamma$', fontsize=_label_size)
             #     plt.text(0.45, -0.08, r'$\Sigma$', fontsize=_label_size)
             #     plt.text(0.57,  0.40, r'N', fontsize=_label_size)
@@ -111,12 +112,12 @@ class BZCreator:
     def getPts(self):
 
         retpts = []
-        for name, sp in self.sps.items():
-            # if (self.pt == PlaneType.h0lplane and sp[self.cz] == 0):  # only points in this plane
-            if (np.dot(PlaneType.GetVector(self.pt), sp) == 0):
-                if (self.pt == PlaneType.h0lplane or self.pt == PlaneType.hhlplane):
+        for sp in self.sps.values():
+            # if (self.pt == PlaneType.H0LPLANE and sp[self.cz] == 0):  # only points in this plane
+            if np.dot(PlaneType.GetVector(self.pt), sp) == 0:
+                if self.pt in (PlaneType.H0LPLANE, PlaneType.HHLPLANE):
                     vec = [sp[0], sp[2]]
-                elif (self.pt == PlaneType.hk0plane):
+                elif self.pt == PlaneType.HK0PLANE:
                     vec = sp[:2]
                 else:
                     raise NotImplementedError
@@ -128,7 +129,7 @@ class BZCreator:
                     pts.append(gpt - vec)
                     pts.append(gpt + vec * inva)
                     pts.append(gpt - vec * inva)
-                    if (self.pt == PlaneType.hk0plane):  # tetragonal
+                    if self.pt == PlaneType.HK0PLANE:  # tetragonal
                         vec.reverse()
                         pts.append(gpt + vec)
                         pts.append(gpt - vec)
@@ -145,11 +146,11 @@ class BZCreator:
         retpts = []
         for gpt in self.gpts:
             pts = []
-            for name, sp in self.sps.items():
-                if (np.dot(PlaneType.GetVector(self.pt), sp) == 0):  # only points in this plane
-                    if (self.pt == PlaneType.h0lplane or self.pt == PlaneType.hhlplane):
+            for sp in self.sps.values():
+                if np.dot(PlaneType.GetVector(self.pt), sp) == 0:  # only points in this plane
+                    if self.pt in (PlaneType.H0LPLANE, PlaneType.HHLPLANE):
                         vec = [sp[0], sp[2]]
-                    elif (self.pt == PlaneType.hk0plane):
+                    elif self.pt == PlaneType.HK0PLANE:
                         vec = sp[:2]
                     else:
                         raise NotImplementedError
@@ -161,7 +162,7 @@ class BZCreator:
                     additem(pts, gpt, vec)
                     vec[:] = [-x for x in vec]
                     additem(pts, gpt, vec)
-                    if (self.pt == PlaneType.hk0plane):  # tetragonal
+                    if self.pt == PlaneType.HK0PLANE:  # tetragonal
                         vec.reverse()
                         additem(pts, gpt, vec)
                         vec[:] = [-x for x in vec]
