@@ -2,7 +2,7 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2022, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
@@ -11,10 +11,10 @@ Utilities for clustering execution of a piece of code to multiple hosts using
 SSH transport.
 """
 
-import sys
-import md5
+import hashlib
 import pickle
 import queue
+import sys
 import threading
 from os import path
 from time import time
@@ -27,13 +27,13 @@ clusterlist = []
 
 def init_cluster():
     try:
-        fp = open(path.expanduser('~/.ufitcluster/hosts'))
-        for line in fp:  # user@host
-            if line.startswith('#'):
-                continue
-            login, host = line.strip().split('@')
-            clusterlist.append((login, host))
-        fp.close()
+        with open(path.expanduser('~/.ufitcluster/hosts'),
+                  encoding='utf-8') as fp:
+            for line in fp:  # user@host
+                if line.startswith('#'):
+                    continue
+                login, host = line.strip().split('@')
+                clusterlist.append((login, host))
     except Exception as err:
         print('Cannot read the list of cluster hosts:', err, file=sys.stderr)
         print('Please create a file %s with one line for each '
@@ -60,13 +60,14 @@ def client_runner(client, task_queue, result_queue):
     while True:
         code, funcname, jobnum, args = task_queue.get()
         if jobnum == -1:
-            print('[C] exiting runner for %s' % client._host)
+            print('[C] exiting runner for %s' % client.ufit_host)
             return
         try:
-            sid = md5.new(str(time()) + str(args)).hexdigest()
+            sidcontents = (str(time()) + str(args)).encode()
+            sid = hashlib.md5(sidcontents).hexdigest()
             sys.stdout.write('.')
             sys.stdout.flush()
-            # print '[C] starting job on %s: %s' % (client._host, sid)
+            # print '[C] starting job on %s: %s' % (client.ufit_host, sid)
             code_footer = '''\nif __name__ == "__main__":
             import pickle
             args = pickle.loads(%r)
@@ -78,22 +79,22 @@ def client_runner(client, task_queue, result_queue):
             fobj.write(code + code_footer)
             fobj.close()
 
-            stdin, stdout, stderr = \
+            _stdin, stdout, _stderr = \
                 client.exec_command('python /tmp/ufit_cluster_%s.py; '
                                     'rm /tmp/ufit_cluster_%s.py' % (sid, sid))
             result = pickle.load(stdout)
             # print '[C] done with job %s: %r' % (sid, result)
             result_queue.put((jobnum, result))
         except Exception as err:
-            print('[C] no result on %s, requeuing: %r' % (client._host, err))
+            print(f'[C] no result on {client.ufit_host}, requeuing: {err!r}')
             task_queue.put((code, funcname, jobnum, args))
             return
 
 
 clients = []
 runners = []
-task_queue = queue.Queue()
-result_queue = queue.Queue()
+global_task_queue = queue.Queue()
+global_result_queue = queue.Queue()
 cluster_setup = False
 
 
@@ -103,14 +104,15 @@ def setup_cluster():
         return
     for i, (user, host) in enumerate(clusterlist):
         client = paramiko.SSHClient()
-        client._host = '%s[%d]' % (host, i)
+        client.ufit_host = '%s[%d]' % (host, i)
         client.set_missing_host_key_policy(paramiko.AutoAddPolicy())
         client.connect(host, username=user, key_filename=keyname,
                        look_for_keys=False)
         clients.append(client)
-        print('[C] opened cluster connection to %s' % client._host)
+        print(f'[C] opened cluster connection to {client.ufit_host}')
         runner = threading.Thread(target=client_runner,
-                                  args=(client, task_queue, result_queue))
+                                  args=(client, global_task_queue,
+                                        global_result_queue))
         runners.append(runner)
         runner.start()
     cluster_setup = True
@@ -118,7 +120,7 @@ def setup_cluster():
 
 def kill_cluster():
     for cl in clients:
-        task_queue.put((None, None, -1, None))  # end!
+        global_task_queue.put((None, None, -1, None))  # end!
         cl.close()
 
 
@@ -128,16 +130,17 @@ def run_cluster(code, funcname, argumentslist):
     retval = [None] * njobs
     returns = 0
     for job in enumerate(argumentslist):
-        task_queue.put((code, funcname) + job)
+        global_task_queue.put((code, funcname) + job)
     while returns < njobs:
         # XXX check if any client is still running
-        jobnum, result = result_queue.get()
+        jobnum, result = global_result_queue.get()
         if isinstance(result, Exception):
             raise result
         retval[jobnum] = result
         returns += 1
     return retval
 
+
 init_cluster()
 
 if __name__ == '__main__':
