@@ -2,17 +2,17 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2022, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
 """Data loading and treatment for ufit."""
 
 from ufit import UFitError
-from ufit.data import ill, nicos, nicos_old, simple, simple_csv, trisp, \
-    llb, cascade, taipan, nist, desy, zebra, dynacool
+from ufit.data import cascade, desy, dynacool, ill, llb, nicos, nicos_old, \
+    nist, simple, simple_csv, taipan, trisp, zebra
+from ufit.data.dataset import Dataset, DatasetList, ImageData, ScanData
 from ufit.data.loader import Loader
-from ufit.data.dataset import Dataset, ScanData, ImageData, DatasetList
 from ufit.plotting import mapping
 
 data_formats_scan = {
@@ -66,7 +66,7 @@ def set_datatemplate(template):
     global_loader.template = template
 
 
-def set_dataformat(format):
+def set_dataformat(fmt):
     """Set the input data format.
 
     Normally ufit autodetects file formats, but this can be overridden using
@@ -86,12 +86,13 @@ def set_dataformat(format):
     * ``'simple'`` - simple whitespace-separated multi-column files
     * ``'simple comma-separated'`` - simple comma-separated multi-column files
     """
-    if format not in data_formats:
+    if fmt not in data_formats:
         raise UFitError('Unknown data format: %r, available formats are %s'
-                        % (format, ', '.join(data_formats)))
-    global_loader.format = format
+                        % (fmt, ', '.join(data_formats)))
+    global_loader.format = fmt
 
 
+# pylint: disable=redefined-builtin
 def read_data(n, xcol='auto', ycol='auto', dycol=None, ncol=None, nscale=1, filter=None):
     """Read a data file.  Returns a :class:`Dataset` object.
 
@@ -116,7 +117,7 @@ def as_data(x, y, dy, name=''):
 
 def read_numors(nstring, binsize, xcol='auto', ycol='auto',
                 dycol=None, ncol=None, nscale=1, floatmerge=True):
-    """Read a number of data files.  Returns a list of :class:`Dataset`\s.
+    """Read a number of data files.  Returns a list of :class:`Dataset`\\s.
 
     :param nstring: A string that gives file numbers, with the operators given
         below.
