@@ -2,7 +2,7 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2021, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
@@ -13,8 +13,8 @@ import re
 from os import path
 from warnings import catch_warnings
 
-from numpy import array, genfromtxt, atleast_2d, concatenate, linalg, sin, \
-    cos, radians, dot
+from numpy import array, atleast_2d, concatenate, cos, dot, genfromtxt, \
+    linalg, radians, sin
 
 from ufit import UFitError
 
@@ -61,6 +61,10 @@ def read_data(filename, fp):
             meta['title'] = line[6:].strip()
         elif line.startswith('FILE_:'):
             meta['filenumber'] = int(line[6:].strip())
+        elif line.startswith('DATE_:'):
+            meta['date'] = line[6:].strip()
+        elif line.startswith('USER_:'):
+            meta['users'] = line[6:].strip()
         elif line.startswith('PARAM:'):
             parts = line[6:].strip().rstrip(',').split(',')
             for part in parts:
@@ -131,18 +135,22 @@ def read_data_d23(filename, fp):
             if section == 1:
                 meta['filenumber'] = int(line.split()[0])
             elif section == 2:
-                # experiment user
+                # experiment, user, date
                 fp.readline()
                 line = fp.readline()
-                meta['experiment'] = line.strip('\x00').split()[0]
+                parts = line.strip('\x00').split(None, 3)
+                meta['instrument'] = parts[0]
+                if len(parts) > 1:
+                    meta['users'] = parts[1]
+                meta['date'] = line.strip('\x00')[14:].rstrip()
             elif section == 3:
-                # experiment title and "scan type" (can be empty)
+                # experiment title (short) and "scan type" (can be empty)
                 fp.readline()
                 line = fp.readline()
-                fields = line.split()
-                meta['title'] = fields[0]
-                if len(fields) > 1:
-                    scantype = fields[1]
+                meta['title'] = line[:72].strip()
+                meta['experiment'] = meta['title']
+                if len(line) >= 72:
+                    scantype = line[72:].strip()
             elif section == 4:
                 # integral metadata, only relevant for interpreting the rest
                 nlines = int(line.split()[1])
@@ -188,23 +196,28 @@ def read_data_d23(filename, fp):
     hkl = None
     if scantype != 'omega' and path.isfile(filename + '.dat'):
         hkl = []
-        fp1 = io.open(filename + '.dat', 'rb')
-        fp1 = io.TextIOWrapper(fp1, 'ascii', 'ignore')
-        for line in fp1:
-            hkl.append([float(x) for x in line.split()[:3]])
+        with io.open(filename + '.dat', 'rb') as fp1:
+            fp1 = io.TextIOWrapper(fp1, 'ascii', 'ignore')
+            for line in fp1:
+                hkl.append([float(x) for x in line.split()[:3]])
         hkl = array(hkl)
         meta['hkle'] = array([(h, k, l, 0) for (h, k, l) in hkl])
         deviations = array([(cs.max()-cs.min()) for cs in arr.T[:4]])
         meta['hkle_vary'] = ['h', 'k', 'l', 'E'][deviations.argmax()]
 
     # otherwise, calculate from UB matrix
-    elif scantype != 'omega':
-        ub = array([[meta['ub(1,1)'], meta['ub(1,2)'], meta['ub(1,3)']],
-                    [meta['ub(2,1)'], meta['ub(2,2)'], meta['ub(2,3)']],
-                    [meta['ub(3,1)'], meta['ub(3,2)'], meta['ub(3,3)']]])
-        assert imeta['icdesc1'] == 1  # gamma
-        assert imeta['icdesc2'] in (2, 16)  # omega
-        assert imeta['icdesc3'] == 5  # chi
+    elif scantype != 'omega' and ncols >= 6:
+        if 'ub(1,1)' in meta:
+            ub = array([[meta['ub(1,1)'], meta['ub(1,2)'], meta['ub(1,3)']],
+                        [meta['ub(2,1)'], meta['ub(2,2)'], meta['ub(2,3)']],
+                        [meta['ub(3,1)'], meta['ub(3,2)'], meta['ub(3,3)']]])
+        else:
+            ub = array([[meta['ub(1 1)'], meta['ub(1 2)'], meta['ub(1 3)']],
+                        [meta['ub(2 1)'], meta['ub(2 2)'], meta['ub(2 3)']],
+                        [meta['ub(3 1)'], meta['ub(3 2)'], meta['ub(3 3)']]])
+        angles = (imeta['icdesc1'], imeta['icdesc2'], imeta['icdesc3'])
+        assert angles in [(1, 2, 5), (1, 16, 5), (2, 1, 5), (16, 1, 5),
+                          (4, 1, 5)]
         hkl = []
         for point in arr:
             gamma, omega, nu = radians(point[3:6])
