@@ -2,18 +2,19 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2022, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
 """Data loader object."""
 
 import io
+import os
 
 from numpy import ones, sqrt
 
 from ufit import UFitError
-from ufit.data.dataset import ScanData, ImageData, DataList, DatasetList
+from ufit.data.dataset import DataList, DatasetList, ImageData, ScanData
 
 
 class Loader:
@@ -35,22 +36,23 @@ class Loader:
             raise UFitError('File %r has no recognized file format' % filename)
         return data_formats[self.format], self.format in data_formats_image
 
-    def _inner_load(self, n, xcol, ycol, dycol=None, ncol=None, nscale=1, filter=None):
+    def _inner_load(self, n, xcol, ycol, dycol=None, ncol=None, nscale=1, filt=None):
         try:
             filename = self.template % n
         except TypeError:
             filename = self.template
-        fobj = io.open(filename, 'rb')
+        fobj = io.open(filename, 'rb')  # pylint: disable=consider-using-with
         rdr, isimg = self._get_reader(filename, fobj)
         if isimg:
             return self._inner_load_image(rdr, filename, fobj, n, ncol, nscale)
         return self._inner_load_scan(rdr, filename, fobj, n, xcol, ycol, dycol,
-                                     ncol, nscale, filter)
+                                     ncol, nscale, filt)
 
     def _inner_load_image(self, rdr, filename, fobj, n, ncol, nscale):
         arr, darr, meta = rdr.read_data(filename, fobj)
         if 'filenumber' not in meta:
             meta['filenumber'] = n
+        meta['file'] = os.path.basename(filename)
         meta['datafilename'] = filename
         if ncol == 'auto':
             ncol = rdr.guess_norm(meta)
@@ -63,10 +65,10 @@ class Loader:
         return dset
 
     def _inner_load_scan(self, rdr, filename, fobj, n,
-                         xcol, ycol, dycol, ncol, nscale, filter):
+                         xcol, ycol, dycol, ncol, nscale, filt):
         colnames, coldata, meta = rdr.read_data(filename, fobj)
-        if filter is not None:
-            for v, k in filter.items():
+        if filt is not None:
+            for v, k in filt.items():
                 if v in colnames:
                     coldata = coldata[coldata.T[colnames.index(v)] == k]
                 else:
@@ -75,8 +77,8 @@ class Loader:
         if 'filenumber' not in meta:
             meta['filenumber'] = n
         meta['datafilename'] = filename
-        for colname, colvalues in zip(colnames, coldata.T):
-            meta['col_%s' % colname] = colvalues
+        for ccolname, colvalues in zip(colnames, coldata.T):
+            meta['col_%s' % ccolname] = colvalues
         datarr = ones((len(coldata), 4))
 
         def colindex(col):
@@ -84,7 +86,7 @@ class Loader:
                 try:
                     return colnames.index(col)
                 except ValueError:
-                    raise UFitError('No such data column: %s' % col)
+                    raise UFitError('No such data column: %s' % col) from None
             elif 1 <= col <= len(colnames):
                 return col - 1   # 1-based indices
             else:
@@ -116,7 +118,7 @@ class Loader:
         def colname(col):
             if col is None:
                 return None
-            elif isinstance(col, str):
+            if isinstance(col, str):
                 return col
             return colnames[col - 1]   # 1-based indices
         if use_hkl:
@@ -128,21 +130,22 @@ class Loader:
         self.sets[n] = dset
         return dset
 
+    # pylint: disable=redefined-builtin
     def load(self, n, xcol, ycol, dycol=None, ncol=None, nscale=1, filter=None):
         try:
             return self._inner_load(n, xcol, ycol, dycol, ncol, nscale, filter)
         except Exception as e:
-            raise UFitError('Could not load data file %d: %s' % (n, e))
+            raise UFitError('Could not load data file %d: %s' % (n, e)) from e
 
     def guess_cols(self, n):
         try:
             filename = self.template % n
         except TypeError:
             filename = self.template
-        fobj = io.open(filename, 'rb')
+        fobj = io.open(filename, 'rb')  # pylint: disable=consider-using-with
         rdr, isimg = self._get_reader(filename, fobj)
         if isimg:
-            arr, darr, meta = rdr.read_data(filename, fobj)
+            _arr, _darr, meta = rdr.read_data(filename, fobj)
             mguess = rdr.guess_norm(meta)
             if mguess:
                 nmon = int(float('%.2g' % meta[mguess]))
@@ -166,6 +169,7 @@ class Loader:
                     dyguess = colnames[2]
         return colnames, xguess, yguess, dyguess, mguess, nmon
 
+    # pylint: disable=redefined-builtin
     def load_numors(self, nstring, binsize, xcol, ycol, dycol=None,
                     ncol=None, nscale=1, floatmerge=True, filter=None):
         """Load a number of data files and merge them according to numor
@@ -183,7 +187,7 @@ class Loader:
             try:
                 return int(a)
             except ValueError:
-                raise UFitError('Invalid file number: %r' % a)
+                raise UFitError('Invalid file number: %r' % a) from None
         # operator "precedence": ',' has lowest, then '+',
         # then '-' and '>' (equal)
         parts1 = nstring.split(',')
