@@ -2,7 +2,7 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2021, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
@@ -71,9 +71,8 @@ def read_data(filename, fp):
     if not dtline.startswith('### NICOS data file'):
         raise UFitError('%r does not appear to be a NICOS data file' %
                         filename)
-    ctime = time.mktime(time.strptime(
-        dtline[len('### NICOS data file, created at '):].strip(),
-        '%Y-%m-%d %H:%M:%S'))
+    meta['date'] = dtline[len('### NICOS data file, created at '):].strip()
+    ctime = time.mktime(time.strptime(meta['date'], '%Y-%m-%d %H:%M:%S'))
     meta['created'] = ctime
     remark = ''
     for line in iter(fp.readline, ''):
@@ -92,7 +91,6 @@ def read_data(filename, fp):
                     val = items[3]
                 except IndexError:
                     continue
-                _unit = None
             key = items[1]
             if key.endswith(('_offset', '_precision')):
                 # we don't need these for fitting
@@ -102,12 +100,14 @@ def read_data(filename, fp):
             if key.endswith('_instrument'):
                 meta['instrument'] = oval.lower()
                 continue
-            elif key.endswith('_proposal'):
+            if key.endswith('_proposal'):
                 meta['experiment'] = oval.lower()
             elif key.endswith('_samplename'):
                 meta['title'] = oval
             elif key.endswith('_remark'):
                 remark = oval
+            elif key == 'Exp_users':
+                meta['users'] = oval
             elif key == 'number':
                 meta['filenumber'] = int(oval)
                 continue
