@@ -2,7 +2,7 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2021, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
@@ -12,7 +12,7 @@ import io
 import re
 import shlex
 
-from numpy import loadtxt, array, concatenate, ones
+from numpy import array, concatenate, loadtxt, ones
 
 
 def guess_cols(colnames, coldata, meta):
@@ -63,9 +63,9 @@ def read_data(filename, fp):
     m = re.match(r'^(\D+)(\d+)', meta1[0])
     meta['experiment'] = m.group(1)
     meta['filenumber'] = int(m.group(2))
-    meta['timestamp'] = meta1[1]
+    meta['date'] = meta1[1]
     meta['scantype'] = meta1[2]
-    meta['title'] = fp.readline()
+    meta['title'] = fp.readline().strip()
 
     meta2 = _read_meta(fp)
     meta['collimation'] = '-'.join(meta2[:4])
