@@ -2,32 +2,34 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2021, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
 """Fitting/plotting GUI for ufit."""
 
+import argparse
 import sys
 import time
-import optparse
 from os import path
 
 t0 = time.time()
 
-from ufit.qt import Qt, QApplication, QSplashScreen, QPixmap, QMessageBox
+# pylint: disable=wrong-import-position
+from ufit.qt import QApplication, QIcon, QMessageBox, QPixmap, QSplashScreen, \
+    Qt
 
 from ufit.gui.loggers import getLogger
+
 logger = getLogger('ufit')
 
 from ufit import __version__
 from ufit.gui.common import SettingGroup
-from ufit.gui.fitter import start as start_fitter
 from ufit.gui.dataloader import start as start_loader
+from ufit.gui.fitter import start as start_fitter
 from ufit.gui.main import UFitMain
 from ufit.utils import extract_template
 
-
 __all__ = ['start_fitter', 'start_loader']
 
 
@@ -35,11 +37,17 @@ def main():
     app = QApplication([])
     app.setOrganizationName('ufit')
     app.setApplicationName('gui')
+    icon = QIcon()
+    icon.addFile(':/appicon.png')
+    icon.addFile(':/appicon-16.png')
+    icon.addFile(':/appicon-48.png')
+    QApplication.setWindowIcon(icon)
 
     pixmap = QPixmap(':/splash.png')
-    splash = QSplashScreen(pixmap, Qt.WindowStaysOnTopHint)
-    splash.showMessage(u'Loading...' + u'\xa0' * 10 + '\n\n',
-                       Qt.AlignRight | Qt.AlignBottom)
+    splash = QSplashScreen(pixmap, Qt.WindowType.WindowStaysOnTopHint)
+    splash.showMessage('Loading...' + '\xa0' * 10 + '\n\n',
+                       Qt.AlignmentFlag.AlignRight |
+                       Qt.AlignmentFlag.AlignBottom)
     splash.show()
     time.sleep(0.1)
     with SettingGroup('main') as settings:
@@ -48,29 +56,30 @@ def main():
             # Execute here the actions to be performed only once after
             # each update (there is nothing there for now, but it could
             # be useful some day...)
-            logger.info('Upgrade to version %s finished' % __version__)
+            logger.info('Upgrade to version %s finished', __version__)
     app.processEvents()
 
-
     def log_unhandled(*exc_info):
         logger.error('Unhandled exception in Qt callback', exc_info=exc_info)
     sys.excepthook = log_unhandled
 
     t1 = time.time()
-    logger.info('Startup: import finished (%.3f s), starting GUI...' % (t1-t0))
+    logger.info('Startup: import finished (%.3f s), starting GUI...', t1-t0)
 
     mainwindow = UFitMain()
 
-    parser = optparse.OptionParser(usage='''\
-    Usage: %prog [-b directory] [.ufit file | data file]
+    parser = argparse.ArgumentParser(usage='''\
+    Usage: %(prog)s [-b directory] [.ufit file | data file]
     ''')
-    parser.add_option('-b', '--browse', action='store', metavar='DIR',
-                      help='open browse window in specified directory')
+    parser.add_argument('-b', '--browse', action='store', metavar='DIR',
+                        help='open browse window in specified directory')
+    parser.add_argument('args', nargs=argparse.REMAINDER,
+                        help='.ufit or data files')
 
-    opts, args = parser.parse_args()
+    opts = parser.parse_args()
 
-    if len(args) >= 1:
-        datafile = path.abspath(args[0])
+    if len(opts.args) >= 1:
+        datafile = path.abspath(opts.args[0])
         if path.isdir(datafile):
             # directory given, treat it as -b argument (browse)
             opts.browse = datafile
@@ -90,6 +99,6 @@ def main():
         mainwindow.dloader.open_browser(opts.browse)
 
     t2 = time.time()
-    logger.info('Startup: loading finished (%.3f s), main window opened' % (t2-t1))
+    logger.info('Startup: loading finished (%.3f s), main window opened', t2-t1)
     splash.deleteLater()
-    app.exec_()
+    app.exec()
