@@ -2,7 +2,7 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2021, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
@@ -11,16 +11,16 @@
 import os
 from os import path
 
-from ufit.qt import pyqtSlot, QByteArray, QMainWindow, QApplication, \
-    QListWidgetItem, QVBoxLayout, QFileDialog
+from ufit.qt import QApplication, QByteArray, QFileDialog, QFont, \
+    QListWidgetItem, QMainWindow, QTextCursor, QVBoxLayout, pyqtSlot
 
 from ufit.data import Loader
-from ufit.utils import extract_template
 from ufit.gui import logger
-from ufit.gui.common import loadUi, MPLCanvas, MPLToolbar, SettingGroup, \
+from ufit.gui.common import MPLCanvas, MPLToolbar, SettingGroup, loadUi, \
     path_to_str
-from ufit.gui.session import session
 from ufit.gui.scanitem import ScanDataItem
+from ufit.gui.session import session
+from ufit.utils import extract_template
 
 
 class Unavailable:
@@ -32,10 +32,13 @@ class Unavailable:
 class FormatWrapper:
     """Wraps a dataset for the purposes of format() not raising exceptions."""
 
-    def __init__(self, dataset):
+    def __init__(self, n, dataset):
+        self.__n = n
         self.__dataset = dataset
 
     def __getattr__(self, attr, default=Unavailable()):
+        if attr == 'n':
+            return self.__n
         val = getattr(self.__dataset, attr, default)
         if isinstance(val, list):
             return ', '.join(map(str, val))
@@ -67,6 +70,11 @@ class BrowseWindow(QMainWindow):
         self.plotframe.setLayout(layout)
         self.sgroup = SettingGroup('browse')
 
+        font = self.fileText.font()
+        font.setFamily('Monospace')
+        font.setStyleHint(QFont.StyleHint.Monospace)
+        self.fileText.setFont(font)
+
         with self.sgroup as settings:
             geometry = settings.value('geometry', QByteArray())
             self.restoreGeometry(geometry)
@@ -74,6 +82,8 @@ class BrowseWindow(QMainWindow):
             self.restoreState(windowstate)
             splitstate = settings.value('splitstate', QByteArray())
             self.splitter.restoreState(splitstate)
+            def_fmtstr = self.fmtStringEdit.text()
+            self.fmtStringEdit.setText(settings.value('fmtstring', def_fmtstr))
             self.monScaleEdit.setText(settings.value('fixedmonval'))
             self.noNormalize.setChecked(bool(settings.value('nonorm')))
 
@@ -104,14 +114,6 @@ class BrowseWindow(QMainWindow):
     def on_refreshBtn_clicked(self):
         self.set_directory(self.rootdir)
 
-    @pyqtSlot()
-    def on_monScaleBtn_clicked(self):
-        self.set_directory(self.rootdir)
-
-    @pyqtSlot()
-    def on_yAxisBtn_clicked(self):
-        self.set_directory(self.rootdir)
-
     def set_directory(self, root):
         self.setWindowTitle('ufit browser - %s' % root)
         self.canvas.axes.text(0.5, 0.5, 'Please wait, loading all data...',
@@ -142,16 +144,16 @@ class BrowseWindow(QMainWindow):
                     res.rescale(const)
                 if self.useFmtString.isChecked():
                     try:
-                        scanLabel = self.fmtStringEdit.text().format(
-                            n, FormatWrapper(res))
+                        scan_label = self.fmtStringEdit.text().format_map(
+                            FormatWrapper(n, res))
                     except Exception:
-                        scanLabel = '%s (%s) - %s | %s' % (
+                        scan_label = '%s (%s) - %s | %s' % (
                             n, res.xcol, res.title, ', '.join(res.environment))
                 else:
-                    scanLabel = '%s (%s) - %s | %s' % (
+                    scan_label = '%s (%s) - %s | %s' % (
                         n, res.xcol, res.title, ', '.join(res.environment))
                 self._data[n] = res
-                QListWidgetItem(scanLabel, self.dataList, n)
+                QListWidgetItem(scan_label, self.dataList, n)
         self.canvas.axes.clear()
         self.canvas.draw()
 
@@ -169,11 +171,21 @@ class BrowseWindow(QMainWindow):
             plotter.plot_data(self._data[numors[0]])
         plotter.draw()
 
+        filename = self._data[numors[-1]].meta['datafilename']
+        with open(filename, 'r', encoding='utf-8', errors='replace') as f:
+            text = f.read()
+        vscrollpos = self.fileText.verticalScrollBar().value()
+        hscrollpos = self.fileText.horizontalScrollBar().value()
+        self.fileText.setPlainText(text)
+        self.fileText.verticalScrollBar().setValue(vscrollpos)
+        self.fileText.horizontalScrollBar().setValue(hscrollpos)
+
     def closeEvent(self, event):
         event.accept()
         with self.sgroup as settings:
             settings.setValue('geometry', self.saveGeometry())
             settings.setValue('windowstate', self.saveState())
             settings.setValue('splitstate', self.splitter.saveState())
+            settings.setValue('fmtstring', self.fmtStringEdit.text())
             settings.setValue('fixedmonval', self.monScaleEdit.text())
             settings.setValue('nonorm', self.noNormalize.isChecked())
