@@ -2,7 +2,7 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2022, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
@@ -12,27 +12,29 @@ import sys
 from io import BytesIO
 from os import path
 
-from ufit.qt import uic, pyqtSignal, QSize, QSettings, Qt, QRectF, \
-    QByteArray, QLineEdit, QSizePolicy, QIcon, QFileDialog, QMessageBox, \
-    QPrinter, QPrintDialog, QPrintPreviewWidget, QPainter, QDialog, \
-    QSvgRenderer
-
 import matplotlib.backends.qt_editor.figureoptions
-from matplotlib.backends.backend_qt5agg import \
-    FigureCanvasQTAgg as FigureCanvas, NavigationToolbar2QT, FigureManagerQT
+from matplotlib import pyplot
 from matplotlib._pylab_helpers import Gcf
+from matplotlib.backend_bases import key_press_handler
+from matplotlib.backends.backend_qtagg import \
+    FigureCanvasQTAgg as FigureCanvas, FigureManagerQT, NavigationToolbar2QT
 from matplotlib.colors import LogNorm
 from matplotlib.figure import Figure
-from matplotlib import pyplot
-from matplotlib.backend_bases import key_press_handler
+
+from ufit.qt import QByteArray, QDialog, QFileDialog, QIcon, QLabel, \
+    QLineEdit, QMessageBox, QPageLayout, QPainter, QPrintDialog, QPrinter, \
+    QPrintPreviewWidget, QRectF, QSettings, QSize, QSizePolicy, QSvgRenderer, \
+    Qt, pyqtSignal, uic
+
 pyplot.rc('font', family='sans-serif')
 pyplot.rc('font', **{'sans-serif': 'Sans Serif, Arial, Helvetica, '
                      'Lucida Grande, DejaVu Sans'})
 
+# pylint: disable=wrong-import-position
 from ufit.gui import logger
+from ufit.gui.ploteditor import figure_edit
 from ufit.gui.session import session
 from ufit.plotting import DataPlotter
-from ufit.gui.ploteditor import figure_edit
 
 # override figure editor with our extended version
 matplotlib.backends.qt_editor.figureoptions.figure_edit = figure_edit
@@ -82,10 +84,11 @@ class MPLCanvas(FigureCanvas):
         self.manager._cidgcf = self.mpl_connect('button_press_event', make_active)
         Gcf.set_active(self.manager)
         self.setParent(parent)
-        self.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
+        self.setSizePolicy(QSizePolicy.Policy.Expanding,
+                           QSizePolicy.Policy.Expanding)
         self.updateGeometry()
         # actually get key events
-        self.setFocusPolicy(Qt.StrongFocus)
+        self.setFocusPolicy(Qt.FocusPolicy.StrongFocus)
         self.mpl_connect('key_press_event', self.key_press)
         # These will not do anything in standalone mode, but do not hurt.
         if maincanvas:
@@ -101,13 +104,11 @@ class MPLCanvas(FigureCanvas):
             self.logzChanged.emit()
 
     def key_press(self, event):
-        if key_press_handler:
-            key_press_handler(event, self)
+        key_press_handler(event, self)
 
     def resizeEvent(self, event):
-        res = FigureCanvas.resizeEvent(self, event)
+        FigureCanvas.resizeEvent(self, event)
         self.figure.tight_layout(pad=2)
-        return res
 
     def print_(self):
         sio = BytesIO()
@@ -116,8 +117,8 @@ class MPLCanvas(FigureCanvas):
         sz = svg.defaultSize()
         aspect = sz.width()/float(sz.height())
 
-        printer = QPrinter(QPrinter.HighResolution)
-        printer.setOrientation(QPrinter.Landscape)
+        printer = QPrinter(QPrinter.PrinterMode.HighResolution)
+        printer.setPageOrientation(QPageLayout.Orientation.Landscape)
 
         dlg = QDialog(self)
         loadUi(dlg, 'printpreview.ui')
@@ -136,11 +137,11 @@ class MPLCanvas(FigureCanvas):
 
         ppw.paintRequested.connect(render)
         dlg.width.valueChanged.connect(sliderchanged)
-        if dlg.exec_() != QDialog.Accepted:
+        if dlg.exec() != QDialog.DialogCode.Accepted:
             return
         self.print_width = dlg.width.value()
         pdlg = QPrintDialog(printer, self)
-        if pdlg.exec_() != QDialog.Accepted:
+        if pdlg.exec() != QDialog.DialogCode.Accepted:
             return
         render(printer)
 
@@ -169,8 +170,10 @@ class MPLToolbar(NavigationToolbar2QT):
 
     toolitems = list(NavigationToolbar2QT.toolitems)
     del toolitems[7]  # subplot adjust
-    toolitems.insert(0, ('Log x', 'Logarithmic X scale', 'log-x', 'logx_callback'))
-    toolitems.insert(1, ('Log y', 'Logarithmic Y scale', 'log-y', 'logy_callback'))
+    toolitems.insert(0, ('Log x', 'Logarithmic X scale', 'log-x',
+                         'logx_callback'))
+    toolitems.insert(1, ('Log y', 'Logarithmic Y scale', 'log-y',
+                         'logy_callback'))
     toolitems.insert(2, ('Log z', 'Logarithmic Z scale for images', 'log-z',
                          'logz_callback'))
     toolitems.insert(3, (None, None, None, None))
@@ -183,7 +186,8 @@ class MPLToolbar(NavigationToolbar2QT):
 
     def __init__(self, *args, **kwds):
         NavigationToolbar2QT.__init__(self, *args, **kwds)
-        self.locLabel.setAlignment(Qt.AlignRight | Qt.AlignVCenter)
+        self.locLabel.setAlignment(Qt.AlignmentFlag.AlignRight |
+                                   Qt.AlignmentFlag.AlignVCenter)
         self._actions['logx_callback'].setCheckable(True)
         self._actions['logy_callback'].setCheckable(True)
         self._actions['logz_callback'].setCheckable(True)
@@ -194,7 +198,7 @@ class MPLToolbar(NavigationToolbar2QT):
             return QIcon(':/' + self.icon_name_map[name])
         return QIcon()
 
-    def home(self):
+    def home(self, *args):
         # always unzoom completely
         if hasattr(self, '_views'):
             self._views.clear()
@@ -255,7 +259,14 @@ class MPLToolbar(NavigationToolbar2QT):
                                     'Please install IPython with qtconsole to '
                                     'activate this function.')
             return
-        w = ConsoleWindow(self)
+        try:
+            w = ConsoleWindow(self)
+        except Exception as err:
+            logger.exception('Qt console window cannot be opened without '
+                             'IPython; import error was:')
+            QMessageBox.information(self, 'ufit', 'IPython qtconsole '
+                                    f'seems to be broken: {err}')
+            return
         w.ipython.executeCommand('from ufit.lab import *')
         w.ipython.pushVariables({
             'fig': self.canvas.figure,
@@ -275,11 +286,11 @@ class MPLToolbar(NavigationToolbar2QT):
                'pgf' in exts or 'raw' in exts:
                 continue
             exts_list = " ".join(['*.%s' % ext for ext in exts])
-            filter = '%s (%s)' % (name, exts_list)
-            filters.append(filter)
+            filt = '%s (%s)' % (name, exts_list)
+            filters.append(filt)
         filters = ';;'.join(filters)
-        fname, _ = QFileDialog.getSaveFileName(self, 'Choose a filename to save to',
-                                               start, filters)
+        fname, _ = QFileDialog.getSaveFileName(
+            self, 'Choose a filename to save to', start, filters)
         if fname:
             try:
                 self.canvas.print_figure(str(fname))
@@ -306,3 +317,46 @@ class SettingGroup:
     def __exit__(self, *args):
         self.settings.endGroup()
         self.settings.sync()
+
+
+class SqueezedLabel(QLabel):
+    """A label that elides text to fit its width."""
+
+    def __init__(self, parent, designMode=False, **kwds):
+        self._fulltext = ''
+        QLabel.__init__(self, parent, **kwds)
+        self._squeeze()
+
+    def resizeEvent(self, event):
+        self._squeeze()
+        QLabel.resizeEvent(self, event)
+
+    def setText(self, text):
+        self._fulltext = text
+        self._squeeze(text)
+
+    def minimumSizeHint(self):
+        sh = QLabel.minimumSizeHint(self)
+        sh.setWidth(-1)
+        return sh
+
+    def _squeeze(self, text=None):
+        if text is None:
+            text = self._fulltext or self.text()
+        fm = self.fontMetrics()
+        labelwidth = self.size().width()
+        squeezed = False
+        new_lines = []
+        for line in text.split('\n'):
+            if fm.horizontalAdvance(line) > labelwidth:
+                squeezed = True
+                new_lines.append(fm.elidedText(
+                    line, Qt.TextElideMode.ElideRight, labelwidth))
+            else:
+                new_lines.append(line)
+        if squeezed:
+            QLabel.setText(self, '\n'.join(new_lines))
+            self.setToolTip(self._fulltext)
+        else:
+            QLabel.setText(self, self._fulltext)
+            self.setToolTip('')
