@@ -2,7 +2,7 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2021, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
@@ -10,14 +10,14 @@ import sys
 from os import path
 
 import numpy as np
-from ufit.qt import uic, QApplication, QMainWindow, QFileDialog, QVBoxLayout
 
+from ufit.qt import QApplication, QFileDialog, QMainWindow, QVBoxLayout, uic
+
+import ufit.bzplot as bp
+import ufit.qreader as qr
 from ufit.gui.common import MPLCanvas, MPLToolbar, SettingGroup, path_to_str
 from ufit.utils import extract_template
 
-import ufit.qreader as qr
-import ufit.bzplot as bp
-
 
 # show the points
 class ReciprocalViewer(QMainWindow):
@@ -161,13 +161,16 @@ class ReciprocalViewer(QMainWindow):
             t.label.set_fontsize(toset[2])
         for t in ax.yaxis.get_major_ticks():
             t.label.set_fontsize(toset[2])
-        if (ax.legend_):
+        if ax.legend_:
             for t in ax.legend_.texts:
                 t.set_fontsize(toset[1])
         self.canvas.plotter.draw()
 
     def addBZ(self):
-        """ Experimental: add brilluin zone. Only Body centered tetragonal now supported. """
+        """
+        Experimental: add Brillouin zone.
+        Only body centered tetragonal now supported.
+        """
 
         # check by vectors
         self.readVectors()
@@ -185,4 +188,4 @@ class ReciprocalViewer(QMainWindow):
 if __name__ == "__main__":
     app = QApplication(sys.argv)
     win = ReciprocalViewer()
-    sys.exit(app.exec_())
+    sys.exit(app.exec())
