@@ -2,7 +2,7 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2021, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
@@ -10,17 +10,16 @@
 
 from os import path
 
-from ufit.qt import pyqtSignal, pyqtSlot, Qt, QWidget, QFileDialog, \
-    QDialogButtonBox, QMessageBox, QMainWindow, QSplitter, QApplication
+from ufit.qt import QApplication, QDialogButtonBox, QFileDialog, QMainWindow, \
+    QMessageBox, QSplitter, Qt, QWidget, pyqtSignal, pyqtSlot
 
-from ufit.data import data_formats, Loader, ImageData
-from ufit.utils import extract_template
+from ufit.data import ImageData, Loader, data_formats
 from ufit.gui import logger
-from ufit.gui.common import loadUi, path_to_str, str_to_path, \
-    MPLCanvas, MPLToolbar
 from ufit.gui.browse import BrowseWindow
-from ufit.gui.common import SettingGroup
+from ufit.gui.common import MPLCanvas, MPLToolbar, SettingGroup, loadUi, \
+    path_to_str, str_to_path
 from ufit.gui.session import session
+from ufit.utils import extract_template
 
 
 class DataLoader(QWidget):
@@ -47,7 +46,12 @@ class DataLoader(QWidget):
             data_template_path = settings.value('last_data_template', '')
             if data_template_path:
                 self.templateEdit.setText(data_template_path)
-                self.set_template(data_template_path, 0, silent=True)
+                try:
+                    self.set_template(data_template_path, 0, silent=True)
+                except Exception:
+                    self.logger.exception(
+                        'while setting data template path: %r',
+                        data_template_path)
 
     def createUI(self, standalone):
         loadUi(self, 'dataloader.ui')
@@ -55,8 +59,8 @@ class DataLoader(QWidget):
         for fmt in sorted(data_formats):
             self.dataformatBox.addItem(fmt)
 
-        self.buttonBox.addButton(QDialogButtonBox.Open)
-        self.buttonBox.addButton('Preview', QDialogButtonBox.NoRole)
+        self.buttonBox.addButton(QDialogButtonBox.StandardButton.Open)
+        self.buttonBox.addButton('Preview', QDialogButtonBox.ButtonRole.NoRole)
 
     def on_session_propsRequested(self):
         session.props.template = self.templateEdit.text()
@@ -73,9 +77,9 @@ class DataLoader(QWidget):
 
     def on_buttonBox_clicked(self, button):
         role = self.buttonBox.buttonRole(button)
-        if role == QDialogButtonBox.RejectRole:
+        if role == QDialogButtonBox.ButtonRole.RejectRole:
             self.closeRequest.emit()
-        elif role == QDialogButtonBox.NoRole:  # "preview"
+        elif role == QDialogButtonBox.ButtonRole.NoRole:  # "preview"
             self.open_data()
         else:  # "open"
             self.open_data(final=True)
@@ -115,18 +119,18 @@ into one set, as well as files 23 and 24.
     def add_numors(self, numors):
         ranges = []
         prev = -1
-        start = None
-        last = None
+        startn = None
+        lastn = None
         for num in numors:
-            if last is not None:
-                if num != last + 1:
-                    ranges.append((start, last))
-                    start = num
+            if lastn is not None:
+                if num != lastn + 1:
+                    ranges.append((startn, lastn))
+                    startn = num
             else:
-                start = num
-            last = num
+                startn = num
+            lastn = num
 
-        ranges.append((start, last))
+        ranges.append((startn, lastn))
 
         s = ''.join(',%s' % ('%s' % s if s == e else '%s-%s' % (s, e))
                     for (s, e) in ranges)
@@ -162,7 +166,7 @@ into one set, as well as files 23 and 24.
             settings.setValue('last_data_template', dtempl)
         self.loader.template = dtempl
         try:
-            cols, xguess, yguess, dyguess, mguess, nmon = \
+            cols, _xguess, _yguess, _dyguess, _mguess, nmon = \
                 self.loader.guess_cols(numor)
         except Exception as e:
             if not silent:
@@ -188,7 +192,7 @@ into one set, as well as files 23 and 24.
         self.filtercolBox.addItem('none')
         self.filtercolBox.setCurrentIndex(0)
 
-        for i, name in enumerate(cols):
+        for name in cols:
             self.xcolBox.addItem(name)
             self.ycolBox.addItem(name)
             self.dycolBox.addItem(name)
@@ -221,19 +225,19 @@ into one set, as well as files 23 and 24.
                 self, 'Error', 'Monitor scale must be integer.')
             return
         if fcol == 'none':
-            filter = None
+            filt = None
         else:
             try:
                 val = float(self.filtervalEdit.text())
             except ValueError:
                 val = bytes(self.filtervalEdit.text(), 'utf-8')
-            filter = {fcol: val}
+            filt = {fcol: val}
         dtempl = path_to_str(self.templateEdit.text())
         self.loader.template = dtempl
         numors = str(self.numorsEdit.text())
         try:
             datas = self.loader.load_numors(
-                numors, prec, xcol, ycol, dycol, mcol, mscale, floatmerge, filter)
+                numors, prec, xcol, ycol, dycol, mcol, mscale, floatmerge, filt)
         except Exception as e:
             self.logger.exception('Error while loading data file')
             QMessageBox.information(self, 'Error', str(e))
@@ -260,8 +264,7 @@ into one set, as well as files 23 and 24.
             if isinstance(data, ImageData):  # XXX this plots only one
                 self.plotter.plot_image(data, multi=True)
                 break
-            else:
-                self.plotter.plot_data(data, multi=True)
+            self.plotter.plot_data(data, multi=True)
         self.plotter.plot_finish(', '.join(xlabels), ', '.join(ylabels),
                                  ', '.join(titles))
         self.plotter.draw()
@@ -270,7 +273,7 @@ into one set, as well as files 23 and 24.
 class DataLoaderMain(QMainWindow):
     def __init__(self, data):
         QMainWindow.__init__(self)
-        layout = QSplitter(Qt.Vertical, self)
+        layout = QSplitter(Qt.Orientation.Vertical, self)
         self.canvas = MPLCanvas(self)
         self.toolbar = MPLToolbar(self.canvas, self)
         layout.addWidget(self.toolbar)
@@ -290,5 +293,5 @@ def start():
     app = QApplication([])
     win = DataLoaderMain()
     win.show()
-    app.exec_()
+    app.exec()
     return win.dloader.last_data
