@@ -2,23 +2,23 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2022, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
 """Data operations panel."""
 
-from numpy import ones, arange, linspace
-from scipy.interpolate import interp1d
+from numpy import arange, linspace, ones
 from scipy.fftpack import fft
+from scipy.interpolate import interp1d
 
-from ufit.qt import pyqtSignal, pyqtSlot, QWidget, QDialog, QMessageBox
+from ufit.qt import QDialog, QMessageBox, QWidget, pyqtSignal, pyqtSlot
 
-from ufit.data.merge import rebin, floatmerge
 from ufit.data.dataset import ScanData
-from ufit.gui.common import loadUi, SettingGroup
-from ufit.gui.session import session
+from ufit.data.merge import floatmerge, rebin
+from ufit.gui.common import SettingGroup, loadUi
 from ufit.gui.mappingitem import MappingItem
+from ufit.gui.session import session
 
 
 class DataOps(QWidget):
@@ -155,7 +155,7 @@ class DataOps(QWidget):
             dlg.xEdit.setText(settings.value('changex', 'x'))
             dlg.yEdit.setText(settings.value('changey', 'y'))
             dlg.dyEdit.setText(settings.value('changedy', 'dy'))
-            if dlg.exec_() != QDialog.Accepted:
+            if dlg.exec() != QDialog.DialogCode.Accepted:
                 return
             settings.setValue('changex', dlg.xEdit.text())
             settings.setValue('changey', dlg.yEdit.text())
@@ -253,7 +253,7 @@ class DataOps(QWidget):
         dlg = QDialog(self)
         loadUi(dlg, 'subtract.ui')
         data2obj = dlg.setList.populate(ScanDataItem)
-        if dlg.exec_() != QDialog.Accepted:
+        if dlg.exec() != QDialog.DialogCode.Accepted:
             return
         witems = dlg.setList.selectedItems()
         if not witems:
@@ -269,7 +269,6 @@ class DataOps(QWidget):
 
         if not dlg.destructBox.isChecked():
             new_model = self.model.copy()
-            from ufit.gui.scanitem import ScanDataItem
             session.add_item(ScanDataItem(new_data, new_model), self.item.group)
         else:
             self.replotRequest.emit(None)
