@@ -2,18 +2,18 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2022, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
 """Data fitter panel."""
 
-from ufit.qt import pyqtSignal, Qt, QApplication, QWidget, QMainWindow, \
-    QGridLayout, QFrame, QLabel, QDialogButtonBox, QCheckBox, QMessageBox, \
-    QSplitter, QComboBox, QKeySequence, QIcon
+from ufit.qt import QApplication, QCheckBox, QComboBox, QDialogButtonBox, \
+    QFrame, QGridLayout, QIcon, QKeySequence, QLabel, QMainWindow, \
+    QMessageBox, QSplitter, Qt, QWidget, pyqtSignal
 
 from ufit.gui import logger
-from ufit.gui.common import loadUi, MPLCanvas, MPLToolbar, SmallLineEdit
+from ufit.gui.common import MPLCanvas, MPLToolbar, SmallLineEdit, loadUi
 from ufit.gui.session import session
 
 
@@ -30,7 +30,8 @@ class Fitter(QWidget):
     pickRequest = pyqtSignal(object)
     replotRequest = pyqtSignal(object)
 
-    def __init__(self, parent, standalone=False, fit_kws={}):
+    def __init__(self, parent, standalone=False, fit_kws=None):
+        fit_kws = fit_kws or {}
         QWidget.__init__(self, parent)
         self.item = getattr(parent, 'item', None)
         self.logger = logger.getChild('fitter')
@@ -48,12 +49,17 @@ class Fitter(QWidget):
         loadUi(self, 'fitter.ui')
 
         if standalone:
-            self.buttonBox.addButton(QDialogButtonBox.Close)
-        self.buttonBox.addButton('Initial guess', QDialogButtonBox.HelpRole)
-        self.buttonBox.addButton('Save params', QDialogButtonBox.ResetRole)
-        self.buttonBox.addButton('Restore saved', QDialogButtonBox.ResetRole)
-        self.buttonBox.addButton('Replot', QDialogButtonBox.ActionRole)
-        fitbtn = self.buttonBox.addButton('Fit', QDialogButtonBox.ApplyRole)
+            self.buttonBox.addButton(QDialogButtonBox.StandardButton.Close)
+        self.buttonBox.addButton(
+            'Initial guess', QDialogButtonBox.ButtonRole.HelpRole)
+        self.buttonBox.addButton(
+            'Save params', QDialogButtonBox.ButtonRole.ResetRole)
+        self.buttonBox.addButton(
+            'Restore saved', QDialogButtonBox.ButtonRole.ResetRole)
+        self.buttonBox.addButton(
+            'Replot', QDialogButtonBox.ButtonRole.ActionRole)
+        fitbtn = self.buttonBox.addButton(
+            'Fit', QDialogButtonBox.ButtonRole.ApplyRole)
         fitbtn.setShortcut(QKeySequence('Ctrl+F'))
         fitbtn.setIcon(QIcon.fromTheme('dialog-ok'))
 
@@ -99,9 +105,10 @@ class Fitter(QWidget):
         for p in self.model.params:
             e0 = QLabel(p.name, self)
             e1 = SmallLineEdit('%.5g' % p.value, self)
-            e2 = QLabel(u'± %.5g' % p.error, self)
-            e2.setTextInteractionFlags(Qt.TextSelectableByMouse |
-                                       Qt.TextSelectableByKeyboard)
+            e2 = QLabel('± %.5g' % (p.error or 0), self)
+            e2.setTextInteractionFlags(
+                Qt.TextInteractionFlag.TextSelectableByMouse |
+                Qt.TextInteractionFlag.TextSelectableByKeyboard)
             e3 = QCheckBox(self)
             e4 = QComboBox(self)
             e4.setEditable(True)
@@ -112,8 +119,10 @@ class Fitter(QWidget):
                 e4.lineEdit().setText('')
             else:
                 e4.lineEdit().setText(p.expr or '')
-            e5 = SmallLineEdit(p.pmin is not None and '%.5g' % p.pmin or '', self)
-            e6 = SmallLineEdit(p.pmax is not None and '%.5g' % p.pmax or '', self)
+            e5 = SmallLineEdit('%.5g' % p.pmin if p.pmin is not None else '',
+                               self)
+            e6 = SmallLineEdit('%.5g' % p.pmax if p.pmax is not None else '',
+                               self)
             e7 = SmallLineEdit(p.delta and '%.5g' % p.delta or '', self)
             ctls = self.param_controls[p] = (e0, e1, e2, e3, e4, e5, e6, e7)
             for j, ctl in enumerate(ctls):
@@ -132,18 +141,19 @@ class Fitter(QWidget):
         self.update_enables()
 
     def update_enables(self, *ignored):
-        for p, ctls in self.param_controls.items():
+        for _p, ctls in self.param_controls.items():
             # if there is an expr...
             if ctls[4].currentText():
                 # disable value and minmax, check "fixed" and disable "fixed"
                 ctls[1].setEnabled(False)
-                ctls[3].setCheckState(Qt.PartiallyChecked)  # implicitly fixed
+                # implicitly fixed
+                ctls[3].setCheckState(Qt.CheckState.PartiallyChecked)
                 ctls[3].setEnabled(False)
                 ctls[5].setEnabled(False)
                 ctls[6].setEnabled(False)
                 ctls[7].setEnabled(False)
             # else, if "fixed" is checked...
-            elif ctls[3].checkState() == Qt.Checked:
+            elif ctls[3].checkState() == Qt.CheckState.Checked:
                 # enable value, but disable expr and minmax
                 ctls[1].setEnabled(True)
                 ctls[4].setEnabled(False)
@@ -155,7 +165,7 @@ class Fitter(QWidget):
                 # enable everything
                 ctls[1].setEnabled(True)
                 ctls[3].setEnabled(True)
-                ctls[3].setCheckState(Qt.Unchecked)
+                ctls[3].setCheckState(Qt.CheckState.Unchecked)
                 ctls[3].setTristate(False)
                 ctls[4].setEnabled(True)
                 ctls[5].setEnabled(True)
@@ -164,13 +174,13 @@ class Fitter(QWidget):
 
     def on_buttonBox_clicked(self, button):
         role = self.buttonBox.buttonRole(button)
-        if role == QDialogButtonBox.RejectRole:
+        if role == QDialogButtonBox.ButtonRole.RejectRole:
             self.closeRequest.emit()
-        elif role == QDialogButtonBox.ApplyRole:
+        elif role == QDialogButtonBox.ButtonRole.ApplyRole:
             self.do_fit()
-        elif role == QDialogButtonBox.ActionRole:
+        elif role == QDialogButtonBox.ButtonRole.ActionRole:
             self.do_plot()
-        elif role == QDialogButtonBox.HelpRole:
+        elif role == QDialogButtonBox.ButtonRole.HelpRole:
             self.do_pick()
         else:
             if button.text() == 'Save params':
@@ -184,7 +194,7 @@ class Fitter(QWidget):
         for p, ctls in self.param_controls.items():
             _, val, _, fx, expr, pmin, pmax, delta = ctls
             p.value = float(val.text()) if val.text() else 0
-            if fx.checkState() == Qt.Checked:
+            if fx.checkState() == Qt.CheckState.Checked:
                 p.expr = str(val.text())
             else:
                 p.expr = str(expr.currentText())
@@ -201,7 +211,7 @@ class Fitter(QWidget):
             p0 = other_params[p.name]
             ctls = self.param_controls[p]
             ctls[1].setText('%.5g' % p0.value)
-            ctls[2].setText(u'± %.5g' % p0.error)
+            ctls[2].setText('± %.5g' % p0.error)
             ctls[3].setChecked(False)
             if p0.expr and is_float(p0.expr):
                 ctls[1].setText(p0.expr)
@@ -288,15 +298,16 @@ class Fitter(QWidget):
 
         for p in res.params:
             self.param_controls[p][1].setText('%.5g' % p.value)
-            self.param_controls[p][2].setText(u'± %.5g' % p.error)
+            self.param_controls[p][2].setText('± %.5g' % (p.error or 0))
 
         self.last_result = res
 
 
 class FitterMain(QMainWindow):
-    def __init__(self, model, data, fit=True, fit_kws={}):
+    def __init__(self, model, data, fit=True, fit_kws=None):
         QMainWindow.__init__(self)
-        layout = QSplitter(Qt.Vertical, self)
+        fit_kws = fit_kws or {}
+        layout = QSplitter(Qt.Orientation.Vertical, self)
         self.canvas = MPLCanvas(self)
         self.toolbar = MPLToolbar(self.canvas, self)
         layout.addWidget(self.toolbar)
@@ -327,5 +338,5 @@ def start(model, data, fit=True, **fit_kws):
     app = QApplication([])
     win = FitterMain(model, data, fit, fit_kws)
     win.show()
-    app.exec_()
+    app.exec()
     return win.fitter.last_result
