@@ -2,32 +2,35 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2022, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
 """Main window for the standalone GUI."""
 
 from os import path
+from pathlib import Path
 
-from ufit.qt import pyqtSlot, Qt, QModelIndex, QByteArray, \
-    QMainWindow, QVBoxLayout, QMessageBox, QMenu, QIcon, QFileDialog, \
-    QDialog, QAction, QActionGroup, QInputDialog, QSplitter, QLabel, QCursor
+import matplotlib.style
 
-from ufit import backends, __version__
-from ufit.data.dataset import ScanData, ImageData
+from ufit.qt import QAction, QActionGroup, QByteArray, QCursor, QDialog, \
+    QFileDialog, QIcon, QInputDialog, QLabel, QMainWindow, QMenu, \
+    QMessageBox, QModelIndex, QSplitter, Qt, QVBoxLayout, pyqtSlot
+
+from ufit import __version__, backends
+from ufit.data.dataset import ImageData, ScanData
 from ufit.gui import logger
+from ufit.gui.annotations import AnnotationWindow
 from ufit.gui.common import MPLCanvas, MPLToolbar, SettingGroup, loadUi, \
     path_to_str
-from ufit.gui.dialogs import ParamExportDialog
-from ufit.gui.dataloader import DataLoader
-from ufit.gui.itemlist import ItemListModel
-from ufit.gui.inspector import InspectorWindow
-from ufit.gui.annotations import AnnotationWindow
-from ufit.gui.scanitem import ScanDataPanel, ScanDataItem
-from ufit.gui.imageitem import ImageDataItem
-from ufit.gui.session import session, temp_session, SessionItem, ItemGroup
 from ufit.gui.coverage import ReciprocalViewer
+from ufit.gui.dataloader import DataLoader
+from ufit.gui.dialogs import ParamExportDialog
+from ufit.gui.imageitem import ImageDataItem
+from ufit.gui.inspector import InspectorWindow
+from ufit.gui.itemlist import ItemListModel
+from ufit.gui.scanitem import ScanDataItem, ScanDataPanel
+from ufit.gui.session import ItemGroup, SessionItem, session, temp_session
 
 max_recent_files = 6
 
@@ -94,10 +97,6 @@ class UFitMain(QMainWindow):
         self.itemlistmodel = ItemListModel()
         self.itemTree.setModel(self.itemlistmodel)
         self.itemlistmodel.reset()
-        self.itemTree.addAction(self.actionMergeData)
-        self.itemTree.addAction(self.actionRemoveData)
-        self.itemTree.addAction(self.menuMoveToGroup.menuAction())
-        self.itemTree.addAction(self.menuCopyToGroup.menuAction())
         self.itemTree.newSelection.connect(self.on_itemTree_newSelection)
 
         # backend selector
@@ -111,6 +110,19 @@ class UFitMain(QMainWindow):
             self.menuBackend.addAction(action)
             action.triggered.connect(self.on_backend_action_triggered)
 
+        # style selector
+        self.style_group = QActionGroup(self)
+        for (i, style) in enumerate(['default'] + matplotlib.style.available):
+            action = QAction(style, self)
+            action.setCheckable(True)
+            if style == 'default':
+                action.setChecked(True)
+            self.style_group.addAction(action)
+            self.menuStyle.addAction(action)
+            action.triggered.connect(self.on_style_action_triggered)
+        self.menuStyle.addSeparator()
+        self.menuStyle.addAction(self.actionCustomStyle)
+
         # manage button
         menu = QMenu(self)
         menu.addAction(self.actionMergeData)
@@ -124,7 +136,19 @@ class UFitMain(QMainWindow):
         menu.addMenu(self.menuRemoveGroup)
         self.manageBtn.setMenu(menu)
 
-        # right-mouse-button menu for canvas
+        # right-mouse-button menu for items in tree
+        menu = self.itemMenu = QMenu(self)
+        menu.addAction(self.actionMergeData)
+        menu.addAction(self.actionRemoveData)
+        menu.addAction(self.menuMoveToGroup.menuAction())
+        menu.addAction(self.menuCopyToGroup.menuAction())
+
+        # right-mouse-button menu for groups in tree
+        menu = self.groupMenu = QMenu(self)
+        menu.addAction(self.actionRenameOneGroup)
+        menu.addAction(self.actionRemoveOneGroup)
+
+        # right-mouse-button menu for items on canvas
         menu = self.canvasMenu = QMenu(self)
         menu.addAction(self.actionUnzoom)
         menu.addAction(self.actionHideFit)
@@ -161,7 +185,7 @@ class UFitMain(QMainWindow):
             elif isinstance(data, ImageData):
                 items.append(ImageDataItem(data))
             else:
-                logger.warning('unknown data type: %s' % data)
+                logger.warning('unknown data type: %s', data)
         session.add_items(items, group)
 
     def on_session_itemsUpdated(self):
@@ -218,10 +242,18 @@ class UFitMain(QMainWindow):
         self.recent_files = []
 
     def select_new_panel(self, panel):
+        active_tab = None
+        if isinstance(self.current_panel, ScanDataPanel):
+            active_tab = self.current_panel.currentIndex()
+
         if panel is not self.current_panel:
             if hasattr(self.current_panel, 'save_limits'):
                 self.current_panel.save_limits()
             self.current_panel = panel
+
+        if active_tab is not None and isinstance(panel, ScanDataPanel):
+            panel.setCurrentIndex(active_tab)
+
         self.stacker.setCurrentWidget(self.current_panel)  # doesn't hurt
 
     def on_canvas_pick(self, event):
@@ -290,22 +322,40 @@ class UFitMain(QMainWindow):
             action = QAction(group.name, self)
 
             def rename(_arg=None, group=group):
-                name = QInputDialog.getText(self, 'ufit', 'Please enter a new name '
-                                            'for the group:', text=group.name)[0]
+                name = QInputDialog.getText(
+                    self, 'ufit', 'Please enter a new name for the group:',
+                    text=group.name)[0]
                 if not name:
                     return
                 session.rename_group(group, name)
             action.triggered.connect(rename)
             self.menuRenameGroup.addAction(action)
 
+    @pyqtSlot()
+    def on_actionRemoveOneGroup_triggered(self):
+        group = self.selected_items(ItemGroup)[0]
+        session.remove_group(group)
+        self.re_expand_tree()
+
+    @pyqtSlot()
+    def on_actionRenameOneGroup_triggered(self):
+        group = self.selected_items(ItemGroup)[0]
+        name = QInputDialog.getText(self, 'ufit', 'Please enter a new name '
+                                    'for the group:', text=group.name)[0]
+        if not name:
+            return
+        session.rename_group(group, name)
+
     @pyqtSlot()
     def on_actionRemoveData_triggered(self):
         items = self.selected_items()
         if not items:
             return
-        if QMessageBox.question(self, 'ufit',
-                                'OK to remove %d item(s)?' % len(items),
-                                QMessageBox.Yes | QMessageBox.No) == QMessageBox.No:
+        q = QMessageBox.question(self, 'ufit',
+                                 'OK to remove %d item(s)?' % len(items),
+                                 QMessageBox.StandardButton.Yes |
+                                 QMessageBox.StandardButton.No)
+        if q == QMessageBox.StandardButton.No:
             return
         session.remove_items(items)
         self.re_expand_tree()
@@ -315,7 +365,7 @@ class UFitMain(QMainWindow):
         dlg = QDialog(self)
         loadUi(dlg, 'reorder.ui')
         data2obj = dlg.itemList.populate()
-        if not dlg.exec_():
+        if not dlg.exec():
             return
         new_structure = []
         for i in range(dlg.itemList.count()):
@@ -347,6 +397,9 @@ class UFitMain(QMainWindow):
         if len(items) == 1 and isinstance(items[0], ItemGroup):
             # a group is selected -- act as if we selected all items
             items = items[0].items
+            # empty group?
+            if not items:
+                return
         if len(items) == 0:
             self.on_loadBtn_clicked()
         elif len(items) == 1:
@@ -392,6 +445,14 @@ class UFitMain(QMainWindow):
             else:
                 self.itemTree.collapse(self.itemlistmodel.index_for_group(group))
 
+    def on_itemTree_customContextMenuRequested(self, point):
+        index = self.itemTree.indexAt(point)
+        if index.isValid():
+            if index.parent().isValid():  # an item
+                self.itemMenu.popup(QCursor.pos())
+            else:  # a group
+                self.groupMenu.popup(QCursor.pos())
+
     @pyqtSlot()
     def on_actionInspector_triggered(self):
         if self.inspector_window:
@@ -448,10 +509,10 @@ class UFitMain(QMainWindow):
         self.canvas.plotter.imgsmoothing = on
         self.current_panel.plot()
 
-    def _get_export_filename(self, filter='ASCII text (*.txt)'):
+    def _get_export_filename(self, filt='ASCII text (*.txt)'):
         initialdir = session.props.get('lastexportdir', session.dirname)
         filename, _ = QFileDialog.getSaveFileName(
-            self, 'Select export file name', initialdir, filter)
+            self, 'Select export file name', initialdir, filt)
         if filename == '':
             return ''
         expfilename = path_to_str(filename)
@@ -480,7 +541,7 @@ class UFitMain(QMainWindow):
     def on_actionExportParams_triggered(self):
         items = self.selected_items(ScanDataItem)
         dlg = ParamExportDialog(self, items)
-        if dlg.exec_() != QDialog.Accepted:
+        if dlg.exec() != QDialog.DialogCode.Accepted:
             return
         expfilename = self._get_export_filename()
         if expfilename:
@@ -501,7 +562,7 @@ class UFitMain(QMainWindow):
         canvas = MPLCanvas(new_win)
         toolbar = MPLToolbar(canvas, new_win)
         new_win.addToolBar(toolbar)
-        splitter = QSplitter(Qt.Vertical, new_win)
+        splitter = QSplitter(Qt.Orientation.Vertical, new_win)
         splitter.addWidget(canvas)
         try:
             from ufit.gui.console import QIPythonWidget
@@ -510,13 +571,20 @@ class UFitMain(QMainWindow):
                          'activate the console part of this window.', new_win)
             splitter.addWidget(lbl)
         else:
-            iw = QIPythonWidget('interactive pylab plotting prompt\n', new_win)
-            iw.pushVariables({'ax': canvas.axes})
-            iw.executeCommand('from ufit.lab import *')
-            iw.executeCommand('sca(ax)')
-            iw.setFocus()
-            iw.redrawme.connect(canvas.draw_idle)
-            splitter.addWidget(iw)
+            try:
+                iw = QIPythonWidget('interactive pylab plotting prompt\n',
+                                    new_win)
+            except Exception as err:
+                lbl = QLabel(f'IPython qtconsole seems to be broken: {err}',
+                             new_win)
+                splitter.addWidget(lbl)
+            else:
+                iw.pushVariables({'ax': canvas.axes})
+                iw.executeCommand('from ufit.lab import *')
+                iw.executeCommand('sca(ax)')
+                iw.setFocus()
+                iw.redrawme.connect(canvas.draw_idle)
+                splitter.addWidget(iw)
         new_win.setCentralWidget(splitter)
         self.current_panel.plot(limits=None, canvas=canvas)
         new_win.show()
@@ -532,12 +600,14 @@ class UFitMain(QMainWindow):
     def check_save(self):
         if not self.isWindowModified():  # nothing there to be saved
             return True
-        resp = QMessageBox.question(self, 'ufit',
-                                    'Save current session?\n%s' % session.filename,
-                                    QMessageBox.Yes | QMessageBox.No | QMessageBox.Cancel)
-        if resp == QMessageBox.Yes:
+        resp = QMessageBox.question(
+            self, 'ufit', 'Save current session?\n%s' %
+            (session.filename or '(unnamed)'),
+            QMessageBox.StandardButton.Yes | QMessageBox.StandardButton.No |
+            QMessageBox.StandardButton.Cancel)
+        if resp == QMessageBox.StandardButton.Yes:
             return self.save_session()
-        elif resp == QMessageBox.No:
+        if resp == QMessageBox.StandardButton.No:
             return True
         return False
 
@@ -587,7 +657,7 @@ class UFitMain(QMainWindow):
             with self.sgroup as settings:
                 settings.setValue('loadfiledirectory', path.dirname(filename))
         except Exception as err:
-            logger.exception('Loading session %r failed' % filename)
+            logger.exception('Loading session %r failed', filename)
             QMessageBox.warning(self, 'Error', 'Loading failed: %s' % err)
         else:
             self.re_expand_tree()
@@ -595,6 +665,16 @@ class UFitMain(QMainWindow):
             # if there are annotations, show the window automatically
             if session.props.get('annotations'):
                 self.on_actionAnnotations_triggered()
+            # apply style (but ignore failures)
+            if session.props.get('mpl_style'):
+                try:
+                    matplotlib.style.use(session.props.mpl_style)
+                except OSError:
+                    pass
+                for action in self.style_group.actions():
+                    if action.text() == session.props.mpl_style:
+                        action.setChecked(True)
+                        break
 
     def insert_session(self, filename):
         temp_session.load(filename)
@@ -652,7 +732,7 @@ class UFitMain(QMainWindow):
             return
         dlg = QDialog(self)
         loadUi(dlg, 'rebin.ui')
-        if dlg.exec_():
+        if dlg.exec():
             try:
                 precision = float(dlg.precisionEdit.text())
             except ValueError:
@@ -680,11 +760,29 @@ class UFitMain(QMainWindow):
     @pyqtSlot()
     def on_actionAbout_triggered(self):
         dlg = QDialog(self)
-        dlg.setWindowFlags(Qt.Dialog | Qt.FramelessWindowHint)
+        dlg.setWindowFlags(Qt.WindowType.Dialog |
+                           Qt.WindowType.FramelessWindowHint)
         loadUi(dlg, 'about.ui')
         dlg.lbl.setText(dlg.lbl.text().replace('VERSION', __version__))
-        dlg.exec_()
+        dlg.exec()
 
     @pyqtSlot()
     def on_backend_action_triggered(self):
-        backends.set_backend(str(self.sender().text()))
+        backends.set_backend(self.sender().text())
+
+    @pyqtSlot()
+    def on_style_action_triggered(self):
+        style = self.sender().text()
+        matplotlib.style.use(style)
+        session.props.mpl_style = style
+        self.current_panel.plot(True)
+
+    @pyqtSlot()
+    def on_actionCustomStyle_triggered(self):
+        filename, _ = QFileDialog.getOpenFileName(
+            self, 'Select style file', str(Path.home()),
+            'Matplotlib styles (*.mplstyle)')
+        if filename:
+            session.props.mpl_style = filename
+            matplotlib.style.use(filename)
+            self.current_panel.plot(True)
