@@ -2,7 +2,7 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2021, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
@@ -10,14 +10,14 @@
 
 import re
 
-from ufit.qt import pyqtSignal, pyqtSlot, QWidget, QListWidgetItem, \
-    QDialogButtonBox, QMessageBox, QInputDialog, QTextCursor, QDialog
+from ufit.qt import QDialog, QDialogButtonBox, QInputDialog, QListWidgetItem, \
+    QMessageBox, QTextCursor, QWidget, pyqtSignal, pyqtSlot
 
+from ufit.gui import logger
+from ufit.gui.common import loadUi
 from ufit.models import concrete_models, eval_model
 from ufit.models.corr import Background
 from ufit.models.peaks import GaussInt
-from ufit.gui import logger
-from ufit.gui.common import loadUi
 
 ident_re = re.compile('[a-zA-Z][a-zA-Z0-9_]*$')
 
@@ -44,14 +44,14 @@ class ModelBuilder(QWidget):
         for model in concrete_models:
             QListWidgetItem(model.__name__, self.premodelsList)
             self.model_dict[model.__name__] = model
-        self.buttonBox.addButton('Check', QDialogButtonBox.NoRole)
-        self.buttonBox.addButton(QDialogButtonBox.Apply)
+        self.buttonBox.addButton('Check', QDialogButtonBox.ButtonRole.NoRole)
+        self.buttonBox.addButton(QDialogButtonBox.StandardButton.Apply)
 
     def on_buttonBox_clicked(self, button):
         role = self.buttonBox.buttonRole(button)
-        if role == QDialogButtonBox.ResetRole:
+        if role == QDialogButtonBox.ButtonRole.ResetRole:
             self.modeldefEdit.setText('')
-        elif role == QDialogButtonBox.NoRole:
+        elif role == QDialogButtonBox.ButtonRole.NoRole:
             self.eval_model()
         else:  # "apply"
             self.eval_model(final=True)
@@ -118,7 +118,7 @@ class ModelBuilder(QWidget):
         dlg = QDialog(self)
         loadUi(dlg, 'custommodel.ui')
         while 1:
-            if dlg.exec_() != QDialog.Accepted:
+            if dlg.exec() != QDialog.DialogCode.Accepted:
                 return
             modelname = str(dlg.nameBox.text())
             params = str(dlg.paramBox.text())
@@ -150,7 +150,7 @@ class ModelBuilder(QWidget):
         if currentmodel:
             prefix = ' + '
         tc = self.modeldefEdit.textCursor()
-        tc.movePosition(QTextCursor.End)
+        tc.movePosition(QTextCursor.MoveOperation.End)
         tc.insertText(prefix + code)
 
     def initialize(self, data, model):
