@@ -2,7 +2,7 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2021, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
@@ -17,12 +17,13 @@ import os.path as osp
 import re
 
 import matplotlib
-from matplotlib import cm, colors as mcolors, markers, image as mimage
+from matplotlib import cm, colors as mcolors, image as mimage, markers
 
 try:
-    import matplotlib.backends.qt_editor.formlayout as formlayout
+    from matplotlib.backends.qt_editor import formlayout
 except ImportError:  # MPL 3.3+
     import matplotlib.backends.qt_editor._formlayout as formlayout
+
 from matplotlib.backends.qt_compat import QtGui
 
 
@@ -87,8 +88,7 @@ def figure_edit(axes, parent=None):
         match = re.match(r"(_line|_image)(\d+)", label)
         if match:
             return match.group(1), int(match.group(2))
-        else:
-            return label, 0
+        return label, 0
 
     # Get / Curves
     linedict = {}
