@@ -2,20 +2,20 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2021, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
 """Models package for ufit."""
 
 from ufit.models.base import *
-from ufit.models.peaks import *
-from ufit.models.corr import *
 from ufit.models.conv import *
+from ufit.models.corr import *
 from ufit.models.other import *
+from ufit.models.peaks import *
 from ufit.models.sqwtas import *
 
-from ufit.models import base, peaks, corr, other, sqwtas
+from ufit.models import base, corr, other, peaks, sqwtas  # isort: skip
 
 __all__ = base.__all__ + peaks.__all__ + corr.__all__ + other.__all__ + \
     sqwtas.__all__
@@ -38,6 +38,7 @@ concrete_models = [
     StraightLine,
     Parabola,
     Cosine,
+    Cosine2,
     Sinc,
     ExpDecay,
     PowerLaw,
