@@ -2,13 +2,13 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2021, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
 """Models for several data corrections."""
 
-from numpy import exp, sqrt, arcsin, tan, pi
+from numpy import arcsin, exp, pi, sqrt, tan
 
 from ufit.models import Model
 
@@ -36,7 +36,7 @@ class Background(Model):
 
     pick_points = ['background']
 
-    def convert_pick(self, b):
+    def convert_pick(self, b):  # pylint: disable=arguments-differ
         return {self.params[0].name: b[1]}
 
 
@@ -60,7 +60,7 @@ class SlopingBackground(Model):
     pick_points = ['left background',
                    'right background']
 
-    def convert_pick(self, b1, b2):
+    def convert_pick(self, b1, b2):  # pylint: disable=arguments-differ
         slope = (b2[1] - b1[1]) / (b2[0] - b1[0])
         return {
             self.params[0].name: b1[1] - slope*b1[0],
