@@ -2,19 +2,20 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2021, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
 """Diverse other models."""
 
-from numpy import cos, sin, exp, pi, log, piecewise, sign, tanh
+from numpy import cos, exp, log, pi, piecewise, sign, sin, tanh
 
-from ufit.param import Param
 from ufit.models.base import Model
+from ufit.param import Param
 
 __all__ = ['Const', 'StraightLine', 'Parabola',
-           'Cosine', 'Sinc', 'ExpDecay', 'PowerLaw', 'BrillouinT', 'BrillouinB']
+           'Cosine', 'Cosine2', 'Sinc',
+           'ExpDecay', 'PowerLaw', 'BrillouinT', 'BrillouinB']
 
 
 class Const(Model):
@@ -58,7 +59,7 @@ class StraightLine(Model):
 
     pick_points = ['one point on curve', 'another point on curve']
 
-    def convert_pick(self, b1, b2):
+    def convert_pick(self, b1, b2):  # pylint: disable=arguments-differ
         slope = (b2[1] - b1[1]) / (b2[0] - b1[0])
         return {
             self.params[0].name: slope,
@@ -85,7 +86,7 @@ class Parabola(Model):
 
     pick_points = ['vertex', 'another point on curve']
 
-    def convert_pick(self, vx, p2):
+    def convert_pick(self, vx, p2):  # pylint: disable=arguments-differ
         return {
             self.params[0].name: vx[0],
             self.params[1].name: vx[1],
@@ -112,7 +113,7 @@ class Cosine(Model):
 
     pick_points = ['a maximum', 'next minimum']
 
-    def convert_pick(self, pmax, pmin):
+    def convert_pick(self, pmax, pmin):  # pylint: disable=arguments-differ
         freq = pi/abs(pmin[0] - pmax[0])
         return {
             self.params[0].name: pmax[1] - pmin[1],          # amplitude
@@ -121,6 +122,34 @@ class Cosine(Model):
         }
 
 
+class Cosine2(Model):
+    """Cosine with phase expressed in units of x
+
+    y = ampl * cos(freq * (x + phase))
+
+    Parameters:
+
+    * `ampl` - amplitude
+    * `freq` - frequency (omega or k)
+    * `phase` - phase
+    """
+    param_names = ['ampl', 'freq', 'phase']
+
+    def __init__(self, name='', ampl=None, freq=None, phase=0):
+        pa, pf, pp = self._init_params(name, self.param_names, locals())
+        self.fcn = lambda p, x: p[pa] * cos(p[pf]*(x + p[pp]))
+
+    pick_points = ['a maximum', 'next minimum']
+
+    def convert_pick(self, pmax, pmin):  # pylint: disable=arguments-differ
+        freq = pi/abs(pmin[0] - pmax[0])
+        return {
+            self.params[0].name: pmax[1] - pmin[1],     # amplitude
+            self.params[1].name: freq,                  # frequency
+            self.params[2].name: (- pmax[0]) % (2*pi),  # phase
+        }
+
+
 class Sinc(Model):
     """Sinc function
 
@@ -160,7 +189,7 @@ class ExpDecay(Model):
 
     pick_points = ['maximum value', 'minimum value', 'half maximum']
 
-    def convert_pick(self, pmax, pmin, phalf):
+    def convert_pick(self, pmax, pmin, phalf):  # pylint: disable=arguments-differ
         return {
             self.params[0].name: pmax[1],
             self.params[1].name: phalf[0]/log(2),
@@ -188,7 +217,7 @@ class PowerLaw(Model):
     pick_points = ['starting point', 'one point on curve',
                    'another point on curve']
 
-    def convert_pick(self, pstart, p1, p2):
+    def convert_pick(self, pstart, p1, p2):  # pylint: disable=arguments-differ
         beta = log(p1[1]/p2[1])/log((p1[0]-pstart[0])/(p2[0]-pstart[0]))
         scale = sign(p1[0] - pstart[0])*(p1[1] / abs(p1[0] - pstart[0])**beta)
         return {
