@@ -2,13 +2,13 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2021, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
 """Models for different peak shapes."""
 
-from numpy import exp, log, sqrt, sin, cos, pi
+from numpy import cos, exp, log, pi, sin, sqrt
 from scipy.special import wofz
 
 from ufit.models import Model
@@ -39,7 +39,7 @@ class Gauss(Model):
 
     pick_points = ['peak', 'width']
 
-    def convert_pick(self, p, w):
+    def convert_pick(self, p, w):  # pylint: disable=arguments-differ
         return {
             self.params[0].name: p[0],  # position
             self.params[1].name: p[1],  # peak amplitude
@@ -58,6 +58,7 @@ class GaussInt(Model):
     """
     param_names = ['pos', 'int', 'fwhm']
 
+    # pylint: disable=redefined-builtin
     def __init__(self, name='', pos=None, int=None, fwhm=None):
         pp, pint, pf = self._init_params(name, self.param_names, locals())
         # integration and fwhm should be positive
@@ -70,7 +71,7 @@ class GaussInt(Model):
 
     pick_points = ['peak', 'width']
 
-    def convert_pick(self, p, w):
+    def convert_pick(self, p, w):  # pylint: disable=arguments-differ
         fwhm = 2*abs(w[0] - p[0])
         return {
             self.params[0].name: p[0],  # position
@@ -100,7 +101,7 @@ class Lorentz(Model):
 
     pick_points = ['peak', 'width']
 
-    def convert_pick(self, p, w):
+    def convert_pick(self, p, w):  # pylint: disable=arguments-differ
         return {
             self.params[0].name: p[0],  # position
             self.params[1].name: p[1],  # peak amplitude
@@ -119,17 +120,19 @@ class LorentzInt(Model):
     """
     param_names = ['pos', 'int', 'fwhm']
 
+    # pylint: disable=redefined-builtin
     def __init__(self, name='', pos=None, int=None, fwhm=None):
         pp, pint, pf = self._init_params(name, self.param_names, locals())
         # integration and fwhm should be positive
         self.params[1].finalize = abs
         self.params[2].finalize = abs
 
-        self.fcn = lambda p, x: 2 * abs(p[pint]) / (pi * p[pf]) / (1 + 4*(x - p[pp])**2/p[pf]**2)
+        self.fcn = lambda p, x: 2 * abs(p[pint]) / (pi * p[pf]) / \
+            (1 + 4*(x - p[pp])**2/p[pf]**2)
 
     pick_points = ['peak', 'width']
 
-    def convert_pick(self, p, w):
+    def convert_pick(self, p, w):  # pylint: disable=arguments-differ
         fwhm = 2*abs(w[0] - p[0])
         return {
             self.params[0].name: p[0],  # position
@@ -165,7 +168,7 @@ class Voigt(Model):
 
     pick_points = ['peak', 'width']
 
-    def convert_pick(self, p, w):
+    def convert_pick(self, p, w):  # pylint: disable=arguments-differ
         return {
             self.params[0].name: p[0],  # position
             self.params[1].name: p[1],  # peak amplitude
@@ -202,7 +205,7 @@ class PseudoVoigt(Model):
 
     pick_points = ['peak', 'width']
 
-    def convert_pick(self, p, w):
+    def convert_pick(self, p, w):  # pylint: disable=arguments-differ
         return {
             self.params[0].name: p[0],  # position
             self.params[1].name: p[1],  # peak amplitude
@@ -240,7 +243,7 @@ class DHO(Model):
 
     pick_points = ['left peak', 'width of left peak', 'right peak']
 
-    def convert_pick(self, p1, w, p2):
+    def convert_pick(self, p1, w, p2):  # pylint: disable=arguments-differ
         return {
             self.params[0].name: 0.5*(p1[0] + p2[0]),  # center
             self.params[1].name: 0.5*abs(p1[0] - p2[0]),  # position
