@@ -2,7 +2,7 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2022, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
@@ -12,10 +12,10 @@ import inspect
 
 from numpy import matrix as zeros
 
-from ufit.rescalc import resmat, calc_MC, calc_MC_cluster, calc_MC_mcstas, \
-    load_cfg, load_par, PARNAMES, CFGNAMES, plot_resatpoint
 from ufit.models.base import Model
 from ufit.param import prepare_params, update_params
+from ufit.rescalc import CFGNAMES, PARNAMES, calc_MC, calc_MC_cluster, \
+    calc_MC_mcstas, load_cfg, load_par, plot_resatpoint, resmat
 
 __all__ = ['ConvolvedScatteringLaw']
 
@@ -55,7 +55,8 @@ class ConvolvedScatteringLaw(Model):
         if isinstance(sqw, str):
             modname, funcname = sqw.split(':')
             mod = __import__(modname)
-            code = open(mod.__file__.rstrip('c')).read()
+            with open(mod.__file__.rstrip('c'), encoding='utf-8') as fp:
+                code = fp.read()
             self._sqwfunc = funcname
             self._sqwcode = code
             self._sqw = getattr(mod, funcname)
@@ -74,7 +75,7 @@ class ConvolvedScatteringLaw(Model):
         cfg_orig = load_cfg(instfiles[0])
         par_orig = load_par(instfiles[1])
 
-        for par in init:
+        for par in init:  # pylint: disable=consider-using-dict-items
             if par == 'par_ALL':
                 par_all = True
             elif par == 'cfg_ALL':
@@ -108,8 +109,8 @@ class ConvolvedScatteringLaw(Model):
             self._instpars = [ip for ip in self._instpars if isinstance(ip, str)]
             instparnames.extend('cfg_' + x for x in CFGNAMES)
             self._instpars.extend(range(len(CFGNAMES)))
-            for i in range(len(CFGNAMES)):
-                init['cfg_' + CFGNAMES[i]] = str(cfg_orig[i])
+            for i, cfgname in enumerate(CFGNAMES):
+                init['cfg_' + cfgname] = str(cfg_orig[i])
 
         # numba compat
         arg_sqw = getattr(self._sqw, 'py_func', self._sqw)
@@ -161,7 +162,7 @@ class ConvolvedScatteringLaw(Model):
         plot_resatpoint(self._resmat.cfg, self._resmat.par, self._resmat)
 
     def simulate(self, data):
-        varying, varynames, dependent, _ = prepare_params(self.params, data.meta)
+        _, _, dependent, _ = prepare_params(self.params, data.meta)
         pd = dict((p.name, p.value) for p in self.params)
         update_params(dependent, data.meta, pd)
         yy = self.fcn(pd, data.x)
