@@ -2,14 +2,15 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2022, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
 """Parameter definition class and helper functions for evaluating parameters."""
 
-import re
 import copy
+import re
+
 import numpy as np
 import scipy
 
@@ -69,12 +70,14 @@ class limited(tuple):
 
        Gauss('peak', pos=0, ampl=limited(0, 100, 50), fwhm=1)
     """
-    def __new__(self, min, max, v):
+    # pylint: disable=redefined-builtin
+    def __new__(cls, min, max, v):
         return (min, max, v)
 
 
 class delta:
     """Give parameter delta together with initial value."""
+    # pylint: disable=redefined-outer-name
     def __init__(self, delta, v):
         self.delta = delta
         self.v = v
@@ -95,6 +98,7 @@ id_re = re.compile('[a-zA-Z_][a-zA-Z0-9_]*$')
 
 
 class Param:
+    # pylint: disable=redefined-outer-name
     def __init__(self, name, value=0, expr=None, pmin=None, pmax=None,
                  overall=False, delta=0, error=0, correl=None, initexpr=None,
                  finalize=lambda x: x):
@@ -181,6 +185,7 @@ class Param:
         return '<Param %s = %.5g +/- %s>' % (
             self.name, self.value, self.error)
 
+    # pylint: disable=redefined-outer-name
     def set_props(self, value, error, expr, pmin, pmax, delta):
         self.value = value
         self.error = error
@@ -224,16 +229,16 @@ def prepare_params(params, meta):
             s = '\n'.join('   %s: %s' % (k, v[1]) for (k, v)
                           in dependent.items())
             raise UFitError('Detected unresolved parameter dependencies:\n' + s)
-        for p, (expr, _) in list(dependent.items()):  # dictionary will change
+        for p, (pexpr, _) in list(dependent.items()):  # dictionary will change
             try:
-                pd[p] = param_eval(expr, pd)
+                pd[p] = param_eval(pexpr, pd)
             except NameError as e:
                 dependent[p][1] = str(e)
             except AttributeError as e:
                 dependent[p][1] = 'depends on data.' + str(e)
             else:
                 del dependent[p]
-                dep_order.append((p, expr))
+                dep_order.append((p, pexpr))
     # pd.pop('__builtins__', None)
 
     return varying, varynames, dep_order, pd
@@ -242,6 +247,6 @@ def prepare_params(params, meta):
 def update_params(parexprs, meta, pd):
     pd.update(expr_namespace)
     pd['data'] = meta
-    for p, expr in parexprs:
-        pd[p] = param_eval(expr, pd)
+    for p, pexpr in parexprs:
+        pd[p] = param_eval(pexpr, pd)
     # pd.pop('__builtins__', None)
