@@ -2,7 +2,7 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2022, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
@@ -10,13 +10,15 @@
 
 from itertools import cycle
 
+import matplotlib
 from numpy import array, isscalar, linspace
 
-import matplotlib
 matplotlib.rc('font', **{'sans-serif': 'Sans Serif, Arial, Helvetica, '
                          'Lucida Grande, Bitstream Vera Sans'})
 matplotlib.rc('savefig', format='pdf')
 
+# pylint: disable=wrong-import-position
+
 from matplotlib import pyplot as pl
 from matplotlib.colors import LogNorm
 
@@ -80,7 +82,7 @@ class DataPlotter:
         self.axes.set_yscale(yscale)
         self.marker_cycle = cycle(self.markers)
 
-    def plot_data(self, data, multi=False, ms=8, offset=0, **kw):
+    def plot_data(self, data, multi=False, ms=10, offset=0, **kw):
         """Plot dataset."""
         axes = self.axes
         if 'marker' in kw:
@@ -110,7 +112,7 @@ class DataPlotter:
             if data.fitmin is not None:
                 axes.axvline(data.fitmin, ls='-', color='gray')
             if data.fitmax is not None:
-                axes.axvline(data.fitmax, ls='-', color='grey')
+                axes.axvline(data.fitmax, ls='-', color='gray')
             axes.set_title('%s\n%s' % (data.title, data.subtitle))
             self.plot_finish(data.xaxis, data.yaxis)
         return color
@@ -124,7 +126,7 @@ class DataPlotter:
         if title is not None:
             axes.set_title(title)
         if self.legend:
-            axes.legend()
+            axes.legend(facecolor='none', ncol=3)
         if self.grid:
             axes.grid(True)
         if self._limits:
@@ -150,13 +152,13 @@ class DataPlotter:
         xxp = linspace(data.x_plot[imin], data.x_plot[imax], nsamples)
         yy = model.fcn(paramvalues, xx)
         if 'label' not in kw:
-            kw['label'] = labels and 'fit' or ''
+            kw['label'] = 'fit' if labels else ''
         self.axes.plot(xxp, yy + offset, 'g', lw=kw.pop('kw', 2), **kw)
         for comp in model.get_components():
             if comp is model:
                 continue
             yy = comp.fcn(paramvalues, xx)
-            kw['label'] = labels and comp.name or ''
+            kw['label'] = comp.name if labels else ''
             self.axes.plot(xxp, yy + offset, '-.', **kw)
 
     def plot_model(self, model, data, labels=True, paramvalues=None,
@@ -171,7 +173,7 @@ class DataPlotter:
         xxp = linspace(data.x_plot[imin], data.x_plot[imax], nsamples)
         yy = model.fcn(paramvalues, xx)
         if 'label' not in kw:
-            kw['label'] = labels and 'fit' or ''
+            kw['label'] = 'fit' if labels else ''
         self.axes.plot(xxp, yy + offset, kw.pop('fmt', 'g'),
                        lw=kw.pop('lw', 2), **kw)
 
@@ -187,7 +189,7 @@ class DataPlotter:
         xxp = linspace(data.x_plot[imin], data.x_plot[imax], nsamples)
         for comp in model.get_components():
             yy = comp.fcn(paramvalues, xx)
-            kw['label'] = labels and comp.name or ''
+            kw['label'] = comp.name if labels else ''
             self.axes.plot(xxp, yy + offset, kw.pop('fmt', '-.'), **kw)
 
     def plot_params(self, params, chisqr):
@@ -195,12 +197,12 @@ class DataPlotter:
         for p in params:
             if p.expr:
                 continue
-            s.append(u'%-12s = %9.4g ± %9.4g' % (p.name, p.value, p.error))
+            s.append('%-12s = %9.4g ± %9.4g' % (p.name, p.value, p.error))
             if p.expr:
                 s[-1] += ' (fixed)'
             if p.overall:
                 s[-1] += ' (global)'
-        s.append(u'%-12s = %9.3f' % (u'chi²/NDF', chisqr))
+        s.append('%-12s = %9.3f' % ('chi²/NDF', chisqr))
         s = '\n'.join(s)
         self.axes.text(0.02, 0.98, s, horizontalalignment='left',
                        verticalalignment='top', size='x-small',
@@ -217,7 +219,7 @@ class DataPlotter:
 
     def plot_image(self, imgdata, multi=False):
         axes = self.axes
-        norm = getattr(self.canvas, 'logz', False) and LogNorm() or None
+        norm = LogNorm() if getattr(self.canvas, 'logz', False) else None
         interp = 'nearest' if not self.imgsmoothing else 'gaussian'
         axes.imshow(imgdata.arr, origin='lower', aspect='equal',
                     interpolation=interp, norm=norm)
