@@ -2,12 +2,10 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2021, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
-import sys
-
 import numpy as np
 
 import ufit.lab as uf
@@ -16,7 +14,7 @@ import ufit.lab as uf
 class QReader:
     """Read and parse the datafiles"""
 
-    def __init__(self, template, numors, tolerance = 0.01):
+    def __init__(self, template, numors, tolerance=0.01):
         """ The reader.
         template, numors - used by ufit read_numors for reading the data
         tolerance - maximum distance of points from plane to be included in reading
@@ -24,8 +22,8 @@ class QReader:
         uf.set_datatemplate(template)
         try:
             self.datas = uf.read_numors(numors, 0)
-        except:
-            print("Unexpected error:", sys.exc_info()[1])
+        except Exception as err:
+            print("Unexpected error:", err)
             self.datas = []
 
         self.tolerance = tolerance
@@ -43,14 +41,15 @@ class QReader:
             if 'hkle' in d.meta:
                 hkle = d.meta['hkle']
             else:
-                print("File %s does not have hkle values for each point, skipping." % d.name)
+                print("File %s does not have hkle values for each point, "
+                      "skipping." % d.name)
                 continue
 
-            for h, k, l, E in hkle:
+            for h, k, l, e in hkle:
                 # transform coordinates to v1 and v2 basis
                 mycoords = np.linalg.solve(v, [h, k, l])
-                if (abs(mycoords[2]) < self.tolerance):
-                    pts.append([mycoords[0], mycoords[1], E])
+                if abs(mycoords[2]) < self.tolerance:
+                    pts.append([mycoords[0], mycoords[1], e])
                 # else:
                 #     print "out of plane reflection:", h, k, l
 
