@@ -2,7 +2,7 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2021, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
@@ -12,14 +12,15 @@ neutrons.instruments.tas.tasres from the neutrons Python package, compiled by
 Marc Janoschek.
 """
 
-import os
 import multiprocessing
+import os
 
-from numpy import pi, radians, degrees, sin, cos, tan, arcsin, arccos, \
-    arctan2, abs, sqrt, real, matrix, diag, cross, dot, array, arange, \
-    zeros, concatenate, reshape, delete, loadtxt
+# pylint: disable=redefined-builtin
+from numpy import abs, arange, arccos, arcsin, arctan2, array, concatenate, \
+    cos, cross, degrees, delete, diag, dot, loadtxt, matrix, pi, radians, \
+    real, reshape, sin, sqrt, tan, zeros
+from numpy.linalg import det, eig, inv, norm
 from numpy.random import randn
-from numpy.linalg import inv, det, eig, norm
 
 
 class unitcell:
@@ -161,6 +162,7 @@ class unitcell:
         repstr = "<Unit cell object>\n"
         repstr += "a      b      c      alpha   beta   gamma\n"
         degree_sym = "deg"
+        # pylint: disable=bad-string-format-type
         repstr += "%2.3fA %2.3fA %2.3fA %3.1f%s   %3.1f%s   %3.1f%s\n" % \
             (self.a, self.b, self.c, degrees(self.alpha), degree_sym,
              degrees(self.beta), degree_sym, degrees(self.gamma), degree_sym)
@@ -372,7 +374,7 @@ class resmat:
         self.calc_popovici()
         self.calc_STrafo()
 
-        self._cache = {}
+        self.m_cache = {}
 
     def calc_popovici(self):
         """Performs the actual calculation.
@@ -885,14 +887,14 @@ Resolution Info:
         # some mcstas bug?!
         if len(arr.T) == 4:
             return [], [], [], [], []
-        kix, kiy, kiz, kfx, kfy, kfz, x, y, z, pi, pf = arr.T
+        kix, kiy, kiz, kfx, kfy, kfz, _x, _y, _z, pi_, pf = arr.T
         # NOTE: cyclic shift of x, y, z here due to different coordinate system
         # conventions in McStas and here:
         # - McStas: z along beam, y upwards, x completes RHS
         # - here:   x along beam, z upwards, y completes RHS
         Q = array((kiz, kix, kiy)) - array((kfz, kfx, kfy))
         w = 2.072*(kix**2 + kiy**2 + kiz**2 - kfx**2 - kfy**2 - kfz**2)
-        p = pi*pf/1e7
+        p = pi_*pf/1e7
         print('%d neutrons for MC calculation' % len(w))
         Q = array([array(dot(self.unitc.cart2rluMat, q))[0] for q in Q.T]).T
         return Q[0], Q[1], Q[2], w, p
@@ -962,8 +964,8 @@ Resolution Info:
         """Set fixed NP matrix for a given M matrix at Q point h,k,l."""
         (h, k, l) = hkl
         TT = real(self.S*matrix([h, k, l]).transpose())
-        cos_theta = TT[0, 0]/sqrt(dot(TT.transpose(), TT))
-        sin_theta = TT[1, 0]/sqrt(dot(TT.transpose(), TT))
+        cos_theta = float(TT[0, 0]/sqrt(dot(TT.transpose(), TT)))
+        sin_theta = float(TT[1, 0]/sqrt(dot(TT.transpose(), TT)))
 
         R = [[cos_theta, sin_theta, 0], [-sin_theta, cos_theta, 0], [0, 0, 1]]
         T = matrix(zeros((4, 4)))
@@ -994,8 +996,8 @@ Resolution Info:
         TT = real(self.S*matrix([h, k, l]).transpose())
         # cos(theta) and sin(theta) are the projections of the Q vector onto
         # the directions V1 and V2
-        cos_theta = TT[0, 0]/sqrt(dot(TT.transpose(), TT))
-        sin_theta = TT[1, 0]/sqrt(dot(TT.transpose(), TT))
+        cos_theta = float(TT[0, 0]/sqrt(dot(TT.transpose(), TT)))
+        sin_theta = float(TT[1, 0]/sqrt(dot(TT.transpose(), TT)))
 
         # ----- Rotation matrix from system of resolution matrix
         # to system defined by V1, V2, V3 => V1,V2 define scattering plane,
@@ -1049,8 +1051,8 @@ Resolution Info:
         msg += '--------------------------\n\n'
         msg += 'NR' + ('Value   :  ').rjust(16) + 'Explanation\n'
         msg += '===============================\n'
-        for i in range(len(self.cfg)):
-            msg += '%2i' % i + ('%1.3f   :  ' % self.cfg[i]).rjust(16) + \
+        for i, cfgitem in enumerate(self.cfg):
+            msg += '%2i' % i + ('%1.3f   :  ' % cfgitem).rjust(16) + \
                 '%s\n' % CFGDESC[i]
         print(msg)
 
@@ -1083,7 +1085,7 @@ Resolution Info:
         xys_x, xys_y = ellipse_coords(hwhm_xp, hwhm_yp, theta)
 
         # ----- 2. Qx, W plane
-        R0P, MP = GaussInt(1, R0, B)
+        _R0P, MP = GaussInt(1, R0, B)
         hwhm_xp, hwhm_yp, theta = calcEllipseAxis(MP)
         xw_x, xw_y = ellipse_coords(hwhm_xp, hwhm_yp, theta)
 
@@ -1093,7 +1095,7 @@ Resolution Info:
         xws_x, xws_y = ellipse_coords(hwhm_xp, hwhm_yp, theta)
 
         # ----- 3. Qy, W plane
-        R0P, MP = GaussInt(0, R0, B)
+        _R0P, MP = GaussInt(0, R0, B)
         hwhm_xp, hwhm_yp, theta = calcEllipseAxis(MP)
         yw_x, yw_y = ellipse_coords(hwhm_xp, hwhm_yp, theta)
 
@@ -1221,6 +1223,7 @@ class dummy_result:
         return self.res
 
 
+# pylint: disable=redefined-outer-name
 def calc_MC_mcstas(x, fit_par, sqw, resmat, NMC):
     """Trial with McStas."""
     results = []
@@ -1234,6 +1237,7 @@ def calc_MC_mcstas(x, fit_par, sqw, resmat, NMC):
     return array(results)
 
 
+# pylint: disable=redefined-outer-name
 def calc_MC(x, fit_par, sqw, resmat, NMC, use_caching=True):
     """Calculates intensity of point in reciprocal space (qh,qk,ql,en) at takes
     into account the spectrometer resolution calculated by resolution class
@@ -1241,12 +1245,13 @@ def calc_MC(x, fit_par, sqw, resmat, NMC, use_caching=True):
     """
     global pool
     if pool is None:
+        # pylint: disable=consider-using-with
         pool = multiprocessing.Pool(multiprocessing.cpu_count())
     results = []
     for QE in x:
         QE = tuple(QE)
-        if QE in resmat._cache and use_caching:
-            b_mat, sigma, R0_corrected = resmat._cache[QE]
+        if QE in resmat.m_cache and use_caching:
+            b_mat, sigma, R0_corrected = resmat.m_cache[QE]
         else:
             resmat.calcResEllipsoid(*QE)
             if resmat.ERROR:
@@ -1258,11 +1263,12 @@ def calc_MC(x, fit_par, sqw, resmat, NMC, use_caching=True):
             sigma = resmat.calcSigma()
             b_mat = resmat.b_mat[0:16]
             R0_corrected = resmat.R0_corrected
-            resmat._cache[QE] = b_mat, sigma, R0_corrected
+            resmat.m_cache[QE] = b_mat, sigma, R0_corrected
         results.append(pool.apply_async(single_mc, (NMC, sqw, fit_par, QE, b_mat,
                                                     sigma, R0_corrected)))
     return array([res.get() for res in results])
 
+
 single_mc_cluster_code = '''
 from numpy import zeros, reshape
 from numpy.random import randn
@@ -1296,8 +1302,8 @@ def calc_MC_cluster(x, fit_par, sqwcode, sqwfunc, resmat, NMC, use_caching=True)
     args = []
     for QE in x:
         QE = tuple(QE)
-        if QE in resmat._cache and use_caching:
-            b_mat, sigma, R0_corrected = resmat._cache[QE]
+        if QE in resmat.m_cache and use_caching:
+            b_mat, sigma, R0_corrected = resmat.m_cache[QE]
         else:
             resmat.calcResEllipsoid(*QE)
             if resmat.ERROR:
@@ -1309,7 +1315,7 @@ def calc_MC_cluster(x, fit_par, sqwcode, sqwfunc, resmat, NMC, use_caching=True)
             sigma = resmat.calcSigma()
             b_mat = resmat.b_mat[0:16]
             R0_corrected = resmat.R0_corrected
-            resmat._cache[QE] = b_mat, sigma, R0_corrected
+            resmat.m_cache[QE] = b_mat, sigma, R0_corrected
         args.append((NMC, fit_par, QE, b_mat, sigma, R0_corrected))
     code = sqwcode + '\n__sqw = %s\n' % sqwfunc + single_mc_cluster_code
     return array(cluster.run_cluster(code, 'single_mc', args))
@@ -1317,7 +1323,7 @@ def calc_MC_cluster(x, fit_par, sqwcode, sqwfunc, resmat, NMC, use_caching=True)
 
 def load_par(filename):
     pars = {}
-    with open(filename) as f:
+    with open(filename, encoding='utf-8') as f:
         for line in f:
             if line.strip():
                 parts = line.split()
@@ -1329,7 +1335,7 @@ def load_par(filename):
 
 def load_cfg(filename):
     pars = []
-    with open(filename) as f:
+    with open(filename, encoding='utf-8') as f:
         for line in f:
             if line.strip():
                 pars.append(float(line.split()[0]))
