@@ -2,7 +2,7 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2022, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
@@ -10,11 +10,11 @@
 
 import copy
 
-from numpy import array, linspace, ravel
 from matplotlib import pyplot as pl
+from numpy import array, linspace, ravel
 
-from ufit.utils import cached_property
 from ufit.plotting import DataPlotter
+from ufit.utils import cached_property
 
 __all__ = ['Result']
 
@@ -158,7 +158,7 @@ def calc_panel_size(num):
 class MultiResult(list):
     def plot(self):
         dims = calc_panel_size(len(self))
-        fig, axarray = pl.subplots(dims[1], dims[0])
+        _fig, axarray = pl.subplots(dims[1], dims[0])
         for res, axes in zip(self, ravel(axarray)):
             res.plotfull(axes=axes)
         # pl.tight_layout()
