@@ -2,7 +2,7 @@
 # *****************************************************************************
 # ufit, a universal scattering fitting suite
 #
-# Copyright (c) 2013-2021, Georg Brandl and contributors.  All rights reserved.
+# Copyright (c) 2013-2025, Georg Brandl and contributors.  All rights reserved.
 # Licensed under a 2-clause BSD license, see LICENSE.
 # *****************************************************************************
 
@@ -10,7 +10,7 @@
 # This file is placed into the public domain.
 
 import os.path
-from subprocess import Popen, PIPE
+from subprocess import PIPE, Popen
 
 __all__ = ['get_version']
 
@@ -21,15 +21,15 @@ GIT_REPO = os.path.join(os.path.dirname(__file__), '..', '.git')
 
 def translate_version(ver):
     ver = ver.lstrip('v').rsplit('-', 2)
-    return '%s.post%s+%s' % tuple(ver) if len(ver) == 3 else ver[0]
+    return f'{ver[0]}.post{ver[1]}+{ver[2]}' if len(ver) == 3 else ver[0]
 
 
 def get_git_version(abbrev=4):
     try:
-        p = Popen(['git', '--git-dir=%s' % GIT_REPO,
-                   'describe', '--abbrev=%d' % abbrev],
-                  stdout=PIPE, stderr=PIPE)
-        stdout, _stderr = p.communicate()
+        with Popen(['git', f'--git-dir={GIT_REPO}',
+                    'describe', f'--abbrev={abbrev}'],
+                   stdout=PIPE, stderr=PIPE) as p:
+            stdout, _stderr = p.communicate()
         return translate_version(stdout.strip().decode('utf-8', 'ignore'))
     except Exception:
         return None
@@ -37,15 +37,15 @@ def get_git_version(abbrev=4):
 
 def read_release_version():
     try:
-        with open(RELEASE_VERSION_FILE) as f:
+        with open(RELEASE_VERSION_FILE, encoding='utf-8') as f:
             return f.readline().strip()
     except Exception:
         return None
 
 
 def write_release_version(version):
-    with open(RELEASE_VERSION_FILE, 'w') as f:
-        f.write("%s\n" % version)
+    with open(RELEASE_VERSION_FILE, 'w', encoding='utf-8') as f:
+        f.write(f'{version}\n')
 
 
 def get_version(abbrev=4):
@@ -58,12 +58,11 @@ def get_version(abbrev=4):
         if git_version != release_version:
             write_release_version(git_version)
         return git_version
-    elif release_version:
+    if release_version:
         return release_version
-    else:
-        raise ValueError('Cannot find a version number - make sure that '
-                         'git is installed or a RELEASE-VERSION file is '
-                         'present!')
+    raise ValueError('Cannot find a version number - make sure that '
+                     'git is installed or a RELEASE-VERSION file is '
+                     'present!')
 
 
 if __name__ == "__main__":
